apiAttachAvailable = u'API\u53ef\u7528'
apiAttachNotAvailable = u'\u7121\u6cd5\u4f7f\u7528'
apiAttachPendingAuthorization = u'\u7b49\u5f85\u6388\u6b0a'
apiAttachRefused = u'\u88ab\u62d2'
apiAttachSuccess = u'\u6210\u529f'
apiAttachUnknown = u'\u4e0d\u660e'
budDeletedFriend = u'\u5df2\u5f9e\u670b\u53cb\u540d\u55ae\u522a\u9664'
budFriend = u'\u670b\u53cb'
budNeverBeenFriend = u'\u5f9e\u672a\u5217\u5165\u670b\u53cb\u540d\u55ae'
budPendingAuthorization = u'\u7b49\u5f85\u6388\u6b0a'
budUnknown = u'\u4e0d\u660e'
cfrBlockedByRecipient = u'\u901a\u8a71\u88ab\u63a5\u6536\u65b9\u5c01\u9396'
cfrMiscError = u'\u5176\u4ed6\u932f\u8aa4'
cfrNoCommonCodec = u'\u6c92\u6709\u901a\u7528 codec'
cfrNoProxyFound = u'\u627e\u4e0d\u5230 proxy'
cfrNotAuthorizedByRecipient = u'\u76ee\u524d\u4f7f\u7528\u8005\u672a\u7372\u63a5\u53d7\u65b9\u6388\u6b0a'
cfrRecipientNotFriend = u'\u63a5\u6536\u65b9\u4e0d\u662f\u670b\u53cb'
cfrRemoteDeviceError = u'\u9060\u7aef\u97f3\u6548\u88dd\u7f6e\u554f\u984c'
cfrSessionTerminated = u'\u901a\u8a71\u7d50\u675f'
cfrSoundIOError = u'\u97f3\u6548\u8f38\u5165/\u8f38\u51fa\u932f\u8aa4'
cfrSoundRecordingError = u'\u9304\u97f3\u932f\u8aa4'
cfrUnknown = u'\u4e0d\u660e'
cfrUserDoesNotExist = u'\u4f7f\u7528\u8005/\u96fb\u8a71\u865f\u78bc\u4e0d\u5b58\u5728'
cfrUserIsOffline = u'\u4ed6/\u5979\u4e0d\u5728\u7dda\u4e0a'
chsAllCalls = u'\u820a\u7248\u5c0d\u8a71'
chsDialog = u'\u5c0d\u8a71'
chsIncomingCalls = u'\u9700\u8981\u591a\u65b9\u63a5\u53d7'
chsLegacyDialog = u'\u820a\u7248\u5c0d\u8a71'
chsMissedCalls = u'\u5c0d\u8a71'
chsMultiNeedAccept = u'\u9700\u8981\u591a\u65b9\u63a5\u53d7'
chsMultiSubscribed = u'\u591a\u65b9\u8a02\u7528'
chsOutgoingCalls = u'\u591a\u65b9\u8a02\u7528'
chsUnknown = u'\u4e0d\u660e'
chsUnsubscribed = u'\u53d6\u6d88\u8a02\u7528'
clsBusy = u'\u5fd9\u7dda'
clsCancelled = u'\u5df2\u53d6\u6d88'
clsEarlyMedia = u'\u9810\u524d\u5a92\u9ad4 (Early Media) \u64ad\u653e\u4e2d'
clsFailed = u'\u5f88\u62b1\u6b49,\u64a5\u865f\u5931\u6557'
clsFinished = u'\u5df2\u7d50\u675f'
clsInProgress = u'\u901a\u8a71\u4e2d'
clsLocalHold = u'\u672c\u6a5f\u901a\u8a71\u4fdd\u7559\u4e2d'
clsMissed = u'\u672a\u63a5\u96fb\u8a71'
clsOnHold = u'\u7b49\u5f85\u4e2d'
clsRefused = u'\u88ab\u62d2'
clsRemoteHold = u'\u9060\u7aef\u901a\u8a71\u4fdd\u7559\u4e2d'
clsRinging = u'\u6b63\u5728\u64a5\u6253'
clsRouting = u'\u9023\u63a5\u4e2d'
clsTransferred = u'\u4e0d\u660e'
clsTransferring = u'\u4e0d\u660e'
clsUnknown = u'\u4e0d\u660e'
clsUnplaced = u'\u5f9e\u672a\u64a5\u6253'
clsVoicemailBufferingGreeting = u'\u554f\u5019\u8a9e\u7de9\u885d\u8655\u7406\u4e2d'
clsVoicemailCancelled = u'\u5df2\u53d6\u6d88\u8a9e\u97f3\u90f5\u4ef6'
clsVoicemailFailed = u'\u7559\u8a00\u4e0a\u50b3\u5931\u6557'
clsVoicemailPlayingGreeting = u'\u554f\u5019\u8a9e\u64ad\u653e\u4e2d'
clsVoicemailRecording = u'\u9304\u88fd\u7559\u8a00'
clsVoicemailSent = u'\u5df2\u50b3\u9001\u8a9e\u97f3\u90f5\u4ef6'
clsVoicemailUploading = u'\u6b63\u5728\u4e0a\u8f09\u8a9e\u97f3\u90f5\u4ef6'
cltIncomingP2P = u'\u64a5\u5165\u540c\u5115 (P2P) \u96fb\u8a71'
cltIncomingPSTN = u'\u64a5\u5165\u96fb\u8a71'
cltOutgoingP2P = u'\u64a5\u51fa\u540c\u5115 (P2P) \u96fb\u8a71'
cltOutgoingPSTN = u'\u64a5\u51fa\u96fb\u8a71'
cltUnknown = u'\u4e0d\u660e'
cmeAddedMembers = u'\u589e\u52a0\u6210\u54e1'
cmeCreatedChatWith = u'\u5df2\u50b3\u9001\u5373\u6642\u8a0a\u606f'
cmeEmoted = u'\u4e0d\u660e'
cmeLeft = u'\u5df2\u96e2\u958b'
cmeSaid = u'\u5df2\u8aaa\u904e'
cmeSawMembers = u'\u770b\u5230\u6210\u54e1'
cmeSetTopic = u'\u8a2d\u7acb\u8a71\u984c'
cmeUnknown = u'\u4e0d\u660e'
cmsRead = u'\u5df2\u95b1\u8b80'
cmsReceived = u'\u5df2\u63a5\u6536'
cmsSending = u'\u50b3\u9001\u4e2d...'
cmsSent = u'\u5df2\u50b3\u9001'
cmsUnknown = u'\u4e0d\u660e'
conConnecting = u'\u9023\u7dda\u4e2d'
conOffline = u'\u96e2\u7dda'
conOnline = u'\u4e0a\u7dda\u4e2d'
conPausing = u'\u6b63\u5728\u66ab\u505c'
conUnknown = u'\u4e0d\u660e'
cusAway = u'\u66ab\u6642\u96e2\u958b'
cusDoNotDisturb = u'\u8acb\u52ff\u6253\u64fe'
cusInvisible = u'\u96b1\u85cf'
cusLoggedOut = u'\u96e2\u7dda'
cusNotAvailable = u'\u7121\u6cd5\u4f7f\u7528'
cusOffline = u'\u96e2\u7dda'
cusOnline = u'\u4e0a\u7dda\u4e2d'
cusSkypeMe = u'\u958b\u653e\u804a\u5929'
cusUnknown = u'\u4e0d\u660e'
cvsBothEnabled = u'\u8996\u8a0a\u50b3\u9001\u8207\u63a5\u6536'
cvsNone = u'\u7121\u8996\u8a0a'
cvsReceiveEnabled = u'\u8996\u8a0a\u63a5\u6536'
cvsSendEnabled = u'\u8996\u8a0a\u50b3\u9001'
cvsUnknown = u''
grpAllFriends = u'\u6240\u6709\u670b\u53cb'
grpAllUsers = u'\u6240\u6709\u4f7f\u7528\u8005'
grpCustomGroup = u'\u81ea\u8a02'
grpOnlineFriends = u'\u7dda\u4e0a\u670b\u53cb'
grpPendingAuthorizationFriends = u'\u7b49\u5f85\u6388\u6b0a'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'\u6700\u8fd1\u806f\u7d61\u904e\u7684\u4f7f\u7528\u8005'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype \u670b\u53cb'
grpSkypeOutFriends = u'SkypeOut \u670b\u53cb'
grpUngroupedFriends = u'\u672a\u5206\u7d44\u7684\u670b\u53cb'
grpUnknown = u'\u4e0d\u660e'
grpUsersAuthorizedByMe = u'\u7d93\u6211\u6388\u6b0a'
grpUsersBlockedByMe = u'\u7d93\u6211\u5c01\u9396'
grpUsersWaitingMyAuthorization = u'\u7b49\u5f85\u6211\u7684\u6388\u6b0a'
leaAddDeclined = u'\u52a0\u5165\u906d\u62d2'
leaAddedNotAuthorized = u'\u88ab\u52a0\u5165\u8005\u5fc5\u9808\u7372\u5f97\u6388\u6b0a'
leaAdderNotFriend = u'\u52a0\u5165\u8005\u5fc5\u9808\u662f\u670b\u53cb'
leaUnknown = u'\u4e0d\u660e'
leaUnsubscribe = u'\u53d6\u6d88\u8a02\u7528'
leaUserIncapable = u'\u4f7f\u7528\u8005\u7121\u6cd5\u901a\u8a71'
leaUserNotFound = u'\u627e\u4e0d\u5230\u4f7f\u7528\u8005'
olsAway = u'\u66ab\u6642\u96e2\u958b'
olsDoNotDisturb = u'\u8acb\u52ff\u6253\u64fe'
olsNotAvailable = u'\u7121\u6cd5\u4f7f\u7528'
olsOffline = u'\u96e2\u7dda'
olsOnline = u'\u4e0a\u7dda\u4e2d'
olsSkypeMe = u'\u958b\u653e\u804a\u5929'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'\u4e0d\u660e'
smsMessageStatusComposing = u''
smsMessageStatusDelivered = u''
smsMessageStatusFailed = u''
smsMessageStatusRead = u''
smsMessageStatusReceived = u''
smsMessageStatusSendingToServer = u''
smsMessageStatusSentToServer = u''
smsMessageStatusSomeTargetsFailed = u''
smsMessageStatusUnknown = u''
smsMessageTypeCCRequest = u''
smsMessageTypeCCSubmit = u''
smsMessageTypeIncoming = u''
smsMessageTypeOutgoing = u''
smsMessageTypeUnknown = u''
smsTargetStatusAcceptable = u''
smsTargetStatusAnalyzing = u''
smsTargetStatusDeliveryFailed = u''
smsTargetStatusDeliveryPending = u''
smsTargetStatusDeliverySuccessful = u''
smsTargetStatusNotRoutable = u''
smsTargetStatusUndefined = u''
smsTargetStatusUnknown = u''
usexFemale = u'\u5973'
usexMale = u'\u7537'
usexUnknown = u'\u4e0d\u660e'
vmrConnectError = u'\u9023\u63a5\u932f\u8aa4'
vmrFileReadError = u'\u6a94\u6848\u8b80\u53d6\u932f\u8aa4'
vmrFileWriteError = u'\u6a94\u6848\u5beb\u5165\u932f\u8aa4'
vmrMiscError = u'\u5176\u4ed6\u932f\u8aa4'
vmrNoError = u'\u7121\u932f\u8aa4'
vmrNoPrivilege = u'\u7121\u8a9e\u97f3\u90f5\u4ef6\u6b0a\u9650'
vmrNoVoicemail = u'\u6c92\u6709\u9019\u7a2e\u8a9e\u97f3\u90f5\u4ef6'
vmrPlaybackError = u'\u64ad\u653e\u932f\u8aa4'
vmrRecordingError = u'\u9304\u97f3\u932f\u8aa4'
vmrUnknown = u'\u4e0d\u660e'
vmsBlank = u'\u7a7a\u767d'
vmsBuffering = u'\u7de9\u885d\u8655\u7406\u4e2d'
vmsDeleting = u'\u6b63\u5728\u522a\u9664'
vmsDownloading = u'\u6b63\u5728\u4e0b\u8f09'
vmsFailed = u'\u5931\u6557'
vmsNotDownloaded = u'\u672a\u4e0b\u8f09'
vmsPlayed = u'\u5df2\u64ad\u653e'
vmsPlaying = u'\u6b63\u5728\u64ad\u653e'
vmsRecorded = u'\u5df2\u9304\u597d'
vmsRecording = u'\u9304\u88fd\u7559\u8a00'
vmsUnknown = u'\u4e0d\u660e'
vmsUnplayed = u'\u672a\u64ad\u653e'
vmsUploaded = u'\u5df2\u4e0a\u8f09'
vmsUploading = u'\u6b63\u5728\u4e0a\u8f09'
vmtCustomGreeting = u'\u81ea\u8a02\u554f\u5019\u8a9e'
vmtDefaultGreeting = u'\u9810\u8a2d\u554f\u5019\u8a9e'
vmtIncoming = u'\u65b0\u7559\u8a00'
vmtOutgoing = u'\u64a5\u51fa'
vmtUnknown = u'\u4e0d\u660e'
vssAvailable = u'\u53ef\u7528'
vssNotAvailable = u'\u7121\u6cd5\u4f7f\u7528'
vssPaused = u'\u5df2\u66ab\u505c'
vssRejected = u'\u5df2\u88ab\u62d2\u7d55'
vssRunning = u'\u6b63\u5728\u9032\u884c'
vssStarting = u'\u958b\u59cb'
vssStopping = u'\u6b63\u5728\u505c\u6b62'
vssUnknown = u'\u4e0d\u660e'
