apiAttachAvailable = u'API je k dispozici'
apiAttachNotAvailable = u'Nedostupn\xfd'
apiAttachPendingAuthorization = u'Nevyr\xedzen\xe1 autorizace'
apiAttachRefused = u'Odm\xedtnuto'
apiAttachSuccess = u'\xdaspech'
apiAttachUnknown = u'Nezn\xe1m\xfd'
budDeletedFriend = u'Odstranen ze seznamu pr\xe1tel'
budFriend = u'Pr\xedtel'
budNeverBeenFriend = u'Nikdy nebyl v seznamu pr\xe1tel'
budPendingAuthorization = u'Nevyr\xedzen\xe1 autorizace'
budUnknown = u'Nezn\xe1m\xfd'
cfrBlockedByRecipient = u'Hovor je blokov\xe1n pr\xedjemcem.'
cfrMiscError = u'Jin\xe1 chyba'
cfrNoCommonCodec = u'Neobvykl\xfd kodek'
cfrNoProxyFound = u'Server proxy nebyl nalezen.'
cfrNotAuthorizedByRecipient = u'Aktu\xe1ln\xed u\u017eivatel nen\xed pr\xedjemcem autorizov\xe1n.'
cfrRecipientNotFriend = u'Pr\xedjemce nen\xed pr\xedtel.'
cfrRemoteDeviceError = u'Chyba zvukov\xe9ho zar\xedzen\xed volan\xe9ho'
cfrSessionTerminated = u'Hovor ukoncen'
cfrSoundIOError = u'Chyba zvukov\xe9ho V/V'
cfrSoundRecordingError = u'Chyba nahr\xe1v\xe1n\xed zvuku'
cfrUnknown = u'Nezn\xe1m\xfd'
cfrUserDoesNotExist = u'U\u017eivatel/telefonn\xed c\xedslo neexistuje.'
cfrUserIsOffline = u'On nebo Ona je Offline'
chsAllCalls = u'Dialog ve star\xe9m stylu'
chsDialog = u'Dialog'
chsIncomingCalls = u'S v\xedce \xfacastn\xedky, je treba prijet\xed'
chsLegacyDialog = u'Dialog ve star\xe9m stylu'
chsMissedCalls = u'Dialog'
chsMultiNeedAccept = u'S v\xedce \xfacastn\xedky, je treba prijet\xed'
chsMultiSubscribed = u'S v\xedce \xfacastn\xedky'
chsOutgoingCalls = u'S v\xedce \xfacastn\xedky'
chsUnknown = u'Nezn\xe1m\xfd'
chsUnsubscribed = u'Odebran\xfd ze seznamu'
clsBusy = u'Obsazeno'
clsCancelled = u'Zru\u0161eno'
clsEarlyMedia = u'Prehr\xe1v\xe1n\xed m\xe9di\xed pred prijet\xedm hovoru'
clsFailed = u'Bohu\u017eel, ne\xfaspe\u0161n\xe9 vol\xe1n\xed!'
clsFinished = u'Ukonceno'
clsInProgress = u'Prob\xedh\xe1 hovor'
clsLocalHold = u'Pridr\u017eeno m\xedstne'
clsMissed = u'Zme\u0161kan\xfd hovor'
clsOnHold = u'Pridr\u017een'
clsRefused = u'Odm\xedtnuto'
clsRemoteHold = u'Pridr\u017eeno vzd\xe1len\xfdm u\u017eivatelem'
clsRinging = u'vol\xe1te'
clsRouting = u'Smerov\xe1n\xed'
clsTransferred = u'Nezn\xe1m\xfd'
clsTransferring = u'Nezn\xe1m\xfd'
clsUnknown = u'Nezn\xe1m\xfd'
clsUnplaced = u'Nekonal se'
clsVoicemailBufferingGreeting = u'Ukl\xe1d\xe1n\xed pozdravu do vyrovn\xe1vac\xed pameti'
clsVoicemailCancelled = u'Hlasov\xe1 zpr\xe1va byla zru\u0161ena'
clsVoicemailFailed = u'Hlasov\xe1 zpr\xe1va ne\xfaspe\u0161n\xe1'
clsVoicemailPlayingGreeting = u'Prehr\xe1v\xe1n\xed pozdravu'
clsVoicemailRecording = u'Nahr\xe1v\xe1n\xed hlasov\xe9 zpr\xe1vy'
clsVoicemailSent = u'Hlasov\xe1 zpr\xe1va byla odesl\xe1na'
clsVoicemailUploading = u'Odes\xedl\xe1n\xed hlasov\xe9 zpr\xe1vy'
cltIncomingP2P = u'Pr\xedchoz\xed hovor v s\xedti P2P'
cltIncomingPSTN = u'Pr\xedchoz\xed telefonn\xed hovor'
cltOutgoingP2P = u'Odchoz\xed hovor v s\xedti P2P'
cltOutgoingPSTN = u'Odchoz\xed telefonn\xed hovor'
cltUnknown = u'Nezn\xe1m\xfd'
cmeAddedMembers = u'Byli prizv\xe1ni clenov\xe9.'
cmeCreatedChatWith = u'Byl vytvoren chat s v\xedce \xfacastn\xedky.'
cmeEmoted = u'Nezn\xe1m\xfd'
cmeLeft = u'Nekdo opustil chat nebo nebyl pribr\xe1n.'
cmeSaid = u'Rekl(a)'
cmeSawMembers = u'\xdacastn\xedk chatu videl ostatn\xed.'
cmeSetTopic = u'Zmena t\xe9matu'
cmeUnknown = u'Nezn\xe1m\xfd'
cmsRead = u'Precteno'
cmsReceived = u'Prijato'
cmsSending = u'Odes\xedl\xe1m...'
cmsSent = u'Odesl\xe1no'
cmsUnknown = u'Nezn\xe1m\xfd'
conConnecting = u'Spojuji'
conOffline = u'Offline'
conOnline = u'Online'
conPausing = u'Pozastavov\xe1n\xed'
conUnknown = u'Nezn\xe1m\xfd'
cusAway = u'Nepr\xedtomn\xfd'
cusDoNotDisturb = u'Neru\u0161it'
cusInvisible = u'Neviditeln\xfd'
cusLoggedOut = u'Offline'
cusNotAvailable = u'Nedostupn\xfd'
cusOffline = u'Offline'
cusOnline = u'Online'
cusSkypeMe = u'Skype Me'
cusUnknown = u'Nezn\xe1m\xfd'
cvsBothEnabled = u'Odes\xedl\xe1n\xed a pr\xedjem videa'
cvsNone = u'Bez videa'
cvsReceiveEnabled = u'Pr\xedjem videa'
cvsSendEnabled = u'Odes\xedl\xe1n\xed videa'
cvsUnknown = u''
grpAllFriends = u'V\u0161ichni pr\xe1tel\xe9'
grpAllUsers = u'V\u0161ichni u\u017eivatel\xe9'
grpCustomGroup = u'Vlastn\xed'
grpOnlineFriends = u'Pr\xe1tel\xe9 online'
grpPendingAuthorizationFriends = u'Nevyr\xedzen\xe1 autorizace'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Ned\xe1vno kontaktovan\xed u\u017eivatel\xe9'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Pr\xe1tel\xe9 pou\u017e\xedvaj\xedc\xed Skype'
grpSkypeOutFriends = u'Pr\xe1tel\xe9 pou\u017e\xedvaj\xedc\xed SkypeOut'
grpUngroupedFriends = u'Nezarazen\xed pr\xe1tel\xe9'
grpUnknown = u'Nezn\xe1m\xfd'
grpUsersAuthorizedByMe = u'Autorizovan\xed'
grpUsersBlockedByMe = u'Blokovan\xed'
grpUsersWaitingMyAuthorization = u'Cekaj\xedc\xed na autorizaci'
leaAddDeclined = u'Prid\xe1n\xed bylo odm\xedtnuto.'
leaAddedNotAuthorized = u'Prid\xe1van\xfd mus\xed b\xfdt autorizov\xe1n.'
leaAdderNotFriend = u'Prid\xe1vaj\xedc\xed mus\xed b\xfdt pr\xedtel.'
leaUnknown = u'Nezn\xe1m\xfd'
leaUnsubscribe = u'Odebran\xfd ze seznamu'
leaUserIncapable = u'U\u017eivatel je nezpusobil\xfd.'
leaUserNotFound = u'U\u017eivatel nebyl nalezen.'
olsAway = u'Nepr\xedtomn\xfd'
olsDoNotDisturb = u'Neru\u0161it'
olsNotAvailable = u'Nedostupn\xfd'
olsOffline = u'Offline'
olsOnline = u'Online'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'????????? ?? SkypeOut'
olsUnknown = u'Nezn\xe1m\xfd'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'\u017dena'
usexMale = u'Mu\u017e'
usexUnknown = u'Nezn\xe1m\xfd'
vmrConnectError = u'Chyba pripojen\xed'
vmrFileReadError = u'Chyba cten\xed souboru'
vmrFileWriteError = u'Chyba z\xe1pisu souboru'
vmrMiscError = u'Jin\xe1 chyba'
vmrNoError = u'Bez chyby'
vmrNoPrivilege = u'Nem\xe1te opr\xe1vnen\xed k hlasov\xe9 schr\xe1nce.'
vmrNoVoicemail = u'Takov\xe1 hlasov\xe1 schr\xe1nka neexistuje.'
vmrPlaybackError = u'Chyba prehr\xe1v\xe1n\xed'
vmrRecordingError = u'Chyba nahr\xe1v\xe1n\xed'
vmrUnknown = u'Nezn\xe1m\xfd'
vmsBlank = u'Pr\xe1zdn\xe9'
vmsBuffering = u'Nac\xedt\xe1n\xed'
vmsDeleting = u'Odstranov\xe1n\xed'
vmsDownloading = u'Stahov\xe1n\xed'
vmsFailed = u'Ne\xfaspe\u0161n\xe9'
vmsNotDownloaded = u'Nesta\u017eeno.'
vmsPlayed = u'Prehr\xe1no'
vmsPlaying = u'Prehr\xe1v\xe1n\xed'
vmsRecorded = u'Nahr\xe1no'
vmsRecording = u'Nahr\xe1v\xe1n\xed hlasov\xe9 zpr\xe1vy'
vmsUnknown = u'Nezn\xe1m\xfd'
vmsUnplayed = u'Neprehr\xe1no'
vmsUploaded = u'Odesl\xe1no'
vmsUploading = u'Odes\xedl\xe1n\xed'
vmtCustomGreeting = u'Vlastn\xed pozdrav'
vmtDefaultGreeting = u'V\xfdchoz\xed pozdrav'
vmtIncoming = u'pr\xedchoz\xed hlasov\xe1 zpr\xe1va'
vmtOutgoing = u'Odchoz\xed'
vmtUnknown = u'Nezn\xe1m\xfd'
vssAvailable = u'Dostupn\xfd'
vssNotAvailable = u'Nedostupn\xfd'
vssPaused = u'Pozastaveno'
vssRejected = u'Odm\xedtnuto'
vssRunning = u'Prob\xedh\xe1'
vssStarting = u'Start'
vssStopping = u'Ukoncov\xe1n\xed'
vssUnknown = u'Nezn\xe1m\xfd'
