apiAttachAvailable = u'API disponibile'
apiAttachNotAvailable = u'Non disponibile'
apiAttachPendingAuthorization = u'In attesa di autorizzazione'
apiAttachRefused = u'Rifiutato'
apiAttachSuccess = u'Riuscito'
apiAttachUnknown = u'Sconosciuto'
budDeletedFriend = u"Eliminato dall'elenco amici"
budFriend = u'Amico'
budNeverBeenFriend = u'Mai stato in elenco amici'
budPendingAuthorization = u'In attesa di autorizzazione'
budUnknown = u'Sconosciuto'
cfrBlockedByRecipient = u'Chiamata bloccata dal destinatario'
cfrMiscError = u'Errori vari'
cfrNoCommonCodec = u'Nessun codec comune'
cfrNoProxyFound = u'Nessun proxy trovato'
cfrNotAuthorizedByRecipient = u'Utente corrente non autorizzato dal destinatario'
cfrRecipientNotFriend = u'Il destinatario non \xe8 un amico'
cfrRemoteDeviceError = u'Problema con la periferica audio remota'
cfrSessionTerminated = u'Sessione conclusa'
cfrSoundIOError = u'Errore I/O audio'
cfrSoundRecordingError = u'Errore di registrazione audio'
cfrUnknown = u'Sconosciuto'
cfrUserDoesNotExist = u'Utente o numero di telefono inesistente'
cfrUserIsOffline = u'Non \xe8 in linea'
chsAllCalls = u'Finestra versione'
chsDialog = u'Dialogo'
chsIncomingCalls = u'In attesa di riscontro'
chsLegacyDialog = u'Finestra versione'
chsMissedCalls = u'Dialogo'
chsMultiNeedAccept = u'In attesa di riscontro'
chsMultiSubscribed = u'Multi-iscritti'
chsOutgoingCalls = u'Multi-iscritti'
chsUnknown = u'Sconosciuto'
chsUnsubscribed = u'Disiscritto'
clsBusy = u'Occupato'
clsCancelled = u'Cancellato'
clsEarlyMedia = u'Esecuzione Early Media in corso (Playing Early Media)'
clsFailed = u'spiacente, chiamata non riuscita!'
clsFinished = u'Terminata'
clsInProgress = u'Chiamata in corso'
clsLocalHold = u'Chiamata in sospeso da utente locale'
clsMissed = u'Chiamata persa'
clsOnHold = u'Sospesa'
clsRefused = u'Rifiutato'
clsRemoteHold = u'Chiamata in sospeso da utente remoto'
clsRinging = u'in chiamata'
clsRouting = u'Routing'
clsTransferred = u'Sconosciuto'
clsTransferring = u'Sconosciuto'
clsUnknown = u'Sconosciuto'
clsUnplaced = u'Mai effettuata'
clsVoicemailBufferingGreeting = u'Buffering del saluto in corso'
clsVoicemailCancelled = u'La voicemail \xe8 stata annullata'
clsVoicemailFailed = u'Messaggio vocale non inviato'
clsVoicemailPlayingGreeting = u'Esecuzione saluto'
clsVoicemailRecording = u'Registrazione del messaggio vocale'
clsVoicemailSent = u'La voicemail \xe8 stata inviata'
clsVoicemailUploading = u'Caricamento voicemail in corso'
cltIncomingP2P = u'Chiamata Peer-to-Peer in arrivo'
cltIncomingPSTN = u'Telefonata in arrivo'
cltOutgoingP2P = u'Chiamata Peer-to-Peer in uscita'
cltOutgoingPSTN = u'Telefonata in uscita'
cltUnknown = u'Sconosciuto'
cmeAddedMembers = u'Membri aggiunti'
cmeCreatedChatWith = u'Chat creata con'
cmeEmoted = u'Sconosciuto'
cmeLeft = u'Uscito'
cmeSaid = u'Detto'
cmeSawMembers = u'Membri visti'
cmeSetTopic = u'Argomento impostato'
cmeUnknown = u'Sconosciuto'
cmsRead = u'Letto'
cmsReceived = u'Ricevuto'
cmsSending = u'Sto inviando...'
cmsSent = u'Inviato'
cmsUnknown = u'Sconosciuto'
conConnecting = u'In connessione'
conOffline = u'Non in linea'
conOnline = u'In linea'
conPausing = u'In pausa'
conUnknown = u'Sconosciuto'
cusAway = u'Torno subito'
cusDoNotDisturb = u'Occupato'
cusInvisible = u'Invisibile'
cusLoggedOut = u'Non in linea'
cusNotAvailable = u'Non disponibile'
cusOffline = u'Non in linea'
cusOnline = u'In linea'
cusSkypeMe = u'Libero per la Chat'
cusUnknown = u'Sconosciuto'
cvsBothEnabled = u'Invio e ricezione video'
cvsNone = u'Assenza video'
cvsReceiveEnabled = u'Ricezione video'
cvsSendEnabled = u'Invio video'
cvsUnknown = u''
grpAllFriends = u'Tutti gli amici'
grpAllUsers = u'Tutti gli utenti'
grpCustomGroup = u'Personalizzato'
grpOnlineFriends = u'Amici online'
grpPendingAuthorizationFriends = u'In attesa di autorizzazione'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Utenti contattati di recente'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Amici Skype'
grpSkypeOutFriends = u'Amici SkypeOut'
grpUngroupedFriends = u'Amici non di gruppo'
grpUnknown = u'Sconosciuto'
grpUsersAuthorizedByMe = u'Autorizzato da me'
grpUsersBlockedByMe = u'Bloccato da me'
grpUsersWaitingMyAuthorization = u'In attesa di mia autorizzazione'
leaAddDeclined = u'Rifiutato'
leaAddedNotAuthorized = u'Deve essere autorizzato'
leaAdderNotFriend = u'Deve essere un amico'
leaUnknown = u'Sconosciuto'
leaUnsubscribe = u'Disiscritto'
leaUserIncapable = u'Utente incapace'
leaUserNotFound = u'Utente non trovato'
olsAway = u'Torno subito'
olsDoNotDisturb = u'Occupato'
olsNotAvailable = u'Non disponibile'
olsOffline = u'Non in linea'
olsOnline = u'In linea'
olsSkypeMe = u'Libero per la Chat'
olsSkypeOut = u'SkypeOut...'
olsUnknown = u'Sconosciuto'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Femmina'
usexMale = u'Maschio'
usexUnknown = u'Sconosciuto'
vmrConnectError = u'Errore di connessione'
vmrFileReadError = u'Errore lettura file'
vmrFileWriteError = u'Errore scrittura file'
vmrMiscError = u'Errori vari'
vmrNoError = u'Nessun errore'
vmrNoPrivilege = u'Nessun privilegio voicemail'
vmrNoVoicemail = u'Voicemail inesistente'
vmrPlaybackError = u'Errore di riproduzione'
vmrRecordingError = u'Errore di registrazione'
vmrUnknown = u'Sconosciuto'
vmsBlank = u'Vuota'
vmsBuffering = u'Buffering'
vmsDeleting = u'Eliminazione in corso'
vmsDownloading = u'Download in corso'
vmsFailed = u'Fallita'
vmsNotDownloaded = u'Non scaricata'
vmsPlayed = u'Riprodotta'
vmsPlaying = u'Riproduzione in corso'
vmsRecorded = u'Registrata'
vmsRecording = u'Registrazione del messaggio vocale'
vmsUnknown = u'Sconosciuto'
vmsUnplayed = u'Non riprodotta'
vmsUploaded = u'Caricata'
vmsUploading = u'Caricamento in corso'
vmtCustomGreeting = u'Saluto personalizzato'
vmtDefaultGreeting = u'Saluto predefinito'
vmtIncoming = u'Messaggio vocale in arrivo'
vmtOutgoing = u'In uscita'
vmtUnknown = u'Sconosciuto'
vssAvailable = u'Disponibile'
vssNotAvailable = u'Non disponibile'
vssPaused = u'In pausa'
vssRejected = u'Rifiutata'
vssRunning = u'In corso'
vssStarting = u'Avvio in corso'
vssStopping = u'Arresto in corso'
vssUnknown = u'Sconosciuto'
