apiAttachAvailable = u'API disponibil'
apiAttachNotAvailable = u'Indisponibil'
apiAttachPendingAuthorization = u'Autorizare \xeen asteptare'
apiAttachRefused = u'Refuzat'
apiAttachSuccess = u'Conectare reusita'
apiAttachUnknown = u'Necunoscut'
budDeletedFriend = u'Elimina cifra 0 dinaintea prefixului local, folosit uneori pentru convorbiri interne. Acest lucru este valabil pentru Marea Britanie si Germania (si nu numai). Pentru apelurile \xeen Italia sau Rusia (si nu numai), cifra 0 trebuie sa ram\xe2na.'
budFriend = u'Prieten'
budNeverBeenFriend = u'Nu a fost niciodata \xeen Lista de prieteni'
budPendingAuthorization = u'Autorizare \xeen asteptare'
budUnknown = u'Necunoscut'
cfrBlockedByRecipient = u'Apel blocat de destinatar'
cfrMiscError = u'Eroare diversa'
cfrNoCommonCodec = u'No common codec found'
cfrNoProxyFound = u'Nu s-a gasit niciun proxy'
cfrNotAuthorizedByRecipient = u'Utilizatorul curent nu este autorizat de destinatar'
cfrRecipientNotFriend = u'Destinatarul nu are statutul de prieten'
cfrRemoteDeviceError = u'Problem with remote sound device'
cfrSessionTerminated = u'Session terminated'
cfrSoundIOError = u'Eroare I/O sunet'
cfrSoundRecordingError = u'Eroare \xeenregistrare sunet'
cfrUnknown = u'Necunoscut'
cfrUserDoesNotExist = u'Utilizator/numar de telefon inexistent'
cfrUserIsOffline = u'User is offline'
chsAllCalls = u'Dialog versiune anterioara'
chsDialog = u'Dialog'
chsIncomingCalls = u'\xcen asteptarea acceptarii de la mai multi utilizatori'
chsLegacyDialog = u'Dialog versiune anterioara'
chsMissedCalls = u'Dialog'
chsMultiNeedAccept = u'\xcen asteptarea acceptarii de la mai multi utilizatori'
chsMultiSubscribed = u'Mai multi utilizatori \xeenregistrati'
chsOutgoingCalls = u'Mai multi utilizatori \xeenregistrati'
chsUnknown = u'Necunoscut'
chsUnsubscribed = u'Neabonat'
clsBusy = u'Busy'
clsCancelled = u'Cancelled'
clsEarlyMedia = u'Redare elemente media premergatoare convorbirii(Early Media)'
clsFailed = u'Sorry, call failed!'
clsFinished = u'Terminat'
clsInProgress = u'Call in Progress'
clsLocalHold = u'\xcen asteptare local'
clsMissed = u'Missed'
clsOnHold = u'On Hold'
clsRefused = u'Refuzat'
clsRemoteHold = u'\xcen asteptare la distanta'
clsRinging = u'Calling'
clsRouting = u'Directionare'
clsTransferred = u'Necunoscut'
clsTransferring = u'Necunoscut'
clsUnknown = u'Necunoscut'
clsUnplaced = u'Apel neefectuat'
clsVoicemailBufferingGreeting = u'Utilizare zona tampon pentru mesaj de \xeent\xe2mpinare'
clsVoicemailCancelled = u'Mesajul vocal a fost revocat'
clsVoicemailFailed = u'Voicemail Failed'
clsVoicemailPlayingGreeting = u'Redare mesaj de \xeent\xe2mpinare'
clsVoicemailRecording = u'Recording'
clsVoicemailSent = u'Mesajul vocal a fost trimis'
clsVoicemailUploading = u'\xcencarcare mesaj vocal'
cltIncomingP2P = u'Apel Peer-to-Peer primit'
cltIncomingPSTN = u'Apel telefonic primit'
cltOutgoingP2P = u'Apel Peer-to-Peer efectuat'
cltOutgoingPSTN = u'Apel telefonic efectuat'
cltUnknown = u'Necunoscut'
cmeAddedMembers = u'Membri adaugati'
cmeCreatedChatWith = u'Chat creat cu'
cmeEmoted = u'Necunoscut'
cmeLeft = u'A parasit conferinta'
cmeSaid = u'A spus'
cmeSawMembers = u'Membri vazuti'
cmeSetTopic = u'Setare subiect'
cmeUnknown = u'Necunoscut'
cmsRead = u'Citit'
cmsReceived = u'Primit'
cmsSending = u'Sending...'
cmsSent = u'Trimis'
cmsUnknown = u'Necunoscut'
conConnecting = u'Connecting'
conOffline = u'Offline'
conOnline = u'Online'
conPausing = u'\xcen pauza'
conUnknown = u'Necunoscut'
cusAway = u'Away'
cusDoNotDisturb = u'Do Not Disturb'
cusInvisible = u'Invisible'
cusLoggedOut = u'Offline'
cusNotAvailable = u'Indisponibil'
cusOffline = u'Logged Out'
cusOnline = u'Online'
cusSkypeMe = u'Skype Me'
cusUnknown = u'Necunoscut'
cvsBothEnabled = u'Trimitere si primire video'
cvsNone = u'Fara video'
cvsReceiveEnabled = u'Primire video'
cvsSendEnabled = u'Trimitere video'
cvsUnknown = u''
grpAllFriends = u'Toti prietenii'
grpAllUsers = u'Toti utilizatorii'
grpCustomGroup = u'Personalizat'
grpOnlineFriends = u'Prieteni conectati'
grpPendingAuthorizationFriends = u'Autorizare \xeen asteptare'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Utilizatori contactati recent'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Prieteni Skype'
grpSkypeOutFriends = u'Prieteni SkypeOut'
grpUngroupedFriends = u'Prieteni negrupati'
grpUnknown = u'Necunoscut'
grpUsersAuthorizedByMe = u'Autorizati de mine'
grpUsersBlockedByMe = u'Blocati de mine'
grpUsersWaitingMyAuthorization = u'\xcen asteptarea autorizarii din partea mea'
leaAddDeclined = u'Adaugare refuzata'
leaAddedNotAuthorized = u'Utilizatorul adaugat trebuie sa fie autorizat'
leaAdderNotFriend = u'Utilizatorul care face adaugarea trebuie sa fie un prieten'
leaUnknown = u'Necunoscut'
leaUnsubscribe = u'Neabonat'
leaUserIncapable = u'Incapacitate utilizator'
leaUserNotFound = u'Nu s-a gasit utilizatorul'
olsAway = u'Away'
olsDoNotDisturb = u'Do Not Disturb'
olsNotAvailable = u'Indisponibil'
olsOffline = u'Offline'
olsOnline = u'Online'
olsSkypeMe = u'SkypeMe'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Necunoscut'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Female'
usexMale = u'Male'
usexUnknown = u'Necunoscut'
vmrConnectError = u'Eroare conectare'
vmrFileReadError = u'Eroare citire fisier'
vmrFileWriteError = u'Eroare scriere fisier'
vmrMiscError = u'Eroare diversa'
vmrNoError = u'Nicio eroare'
vmrNoPrivilege = u'Fara privilegii pentru mesaje vocale'
vmrNoVoicemail = u'Mesaj vocal inexistent'
vmrPlaybackError = u'Eroare redare'
vmrRecordingError = u'Eroare \xeenregistrare'
vmrUnknown = u'Necunoscut'
vmsBlank = u'Gol'
vmsBuffering = u'Utilizare zona tampon'
vmsDeleting = u'Stergere'
vmsDownloading = u'Descarcare'
vmsFailed = u'Nereusit'
vmsNotDownloaded = u'Nedescarcat'
vmsPlayed = u'Redat'
vmsPlaying = u'Redare'
vmsRecorded = u'\xcenregistrat'
vmsRecording = u'Recording Voicemail'
vmsUnknown = u'Necunoscut'
vmsUnplayed = u'Neredat'
vmsUploaded = u'\xcencarcat'
vmsUploading = u'\xcencarcare'
vmtCustomGreeting = u'Mesaj de \xeent\xe2mpinare personalizat'
vmtDefaultGreeting = u'Mesaj de \xeent\xe2mpinare implicit'
vmtIncoming = u'Incoming'
vmtOutgoing = u'De expediat'
vmtUnknown = u'Necunoscut'
vssAvailable = u'Disponibil'
vssNotAvailable = u'Indisponibil'
vssPaused = u'\xcen pauza'
vssRejected = u'Respins'
vssRunning = u'\xcen executie'
vssStarting = u'Lansare'
vssStopping = u'\xcentrerupere'
vssUnknown = u'Necunoscut'
