"""Language translations.
"""

import ar
import bg
import cs
import cz
import da
import de
import el
import en
import en
import es
import et
import fi
import fr
import he
import hu
import it
import ja
import ko
import lt
import lv
import nl
import no
import pl
import pl
import pp
import pt
import ro
import ru
import sv
import tr
import x1
