apiAttachAvailable = u'API beschikbaar'
apiAttachNotAvailable = u'Niet beschikbaar'
apiAttachPendingAuthorization = u'Wacht op autorisatie'
apiAttachRefused = u'Geweigerd'
apiAttachSuccess = u'Succes'
apiAttachUnknown = u'Onbekend'
budDeletedFriend = u'Van de vriendenlijst verwijderd'
budFriend = u'Vriend'
budNeverBeenFriend = u'Nooit op de vriendenlijst gestaan'
budPendingAuthorization = u'Wacht op autorisatie'
budUnknown = u'Onbekend'
cfrBlockedByRecipient = u'Gesprek geblokkeerd door ontvanger'
cfrMiscError = u'Overige fout'
cfrNoCommonCodec = u'No common codec found'
cfrNoProxyFound = u'Geen proxy gevonden'
cfrNotAuthorizedByRecipient = u'Huidige gebruiker niet door ontvanger geautoriseerd'
cfrRecipientNotFriend = u'Ontvanger geen vriend'
cfrRemoteDeviceError = u'Problem with remote sound device'
cfrSessionTerminated = u'Session terminated'
cfrSoundIOError = u'Geluidsfout'
cfrSoundRecordingError = u'Geluidsopnamefout'
cfrUnknown = u'Onbekend'
cfrUserDoesNotExist = u'Gebruiker/telefoonnummer bestaat niet'
cfrUserIsOffline = u'User is offline'
chsAllCalls = u'Erfenisdialoog'
chsDialog = u'Dialoog'
chsIncomingCalls = u'Multi moet geaccepteerd worden'
chsLegacyDialog = u'Erfenisdialoog'
chsMissedCalls = u'Dialoog'
chsMultiNeedAccept = u'Multi moet geaccepteerd worden'
chsMultiSubscribed = u'Multi ingeschreven'
chsOutgoingCalls = u'Multi ingeschreven'
chsUnknown = u'Onbekend'
chsUnsubscribed = u'Niet ingeschreven'
clsBusy = u'Busy'
clsCancelled = u'Cancelled'
clsEarlyMedia = u'Early Media aan het afspelen'
clsFailed = u'Sorry, call failed!'
clsFinished = u'Be\xebindigd'
clsInProgress = u'Call in Progress'
clsLocalHold = u'Zelf in de wacht gezet'
clsMissed = u'Missed'
clsOnHold = u'On Hold'
clsRefused = u'Geweigerd'
clsRemoteHold = u'In de wacht gezet door ontvanger'
clsRinging = u'Calling'
clsRouting = u'Bezig met routeren'
clsTransferred = u'Onbekend'
clsTransferring = u'Onbekend'
clsUnknown = u'Onbekend'
clsUnplaced = u'Nooit plaatsgevonden'
clsVoicemailBufferingGreeting = u'Begroeting wordt gebufferd'
clsVoicemailCancelled = u'Voicemail is geannuleerd'
clsVoicemailFailed = u'Voicemail Failed'
clsVoicemailPlayingGreeting = u'Begroeting wordt afgespeeld'
clsVoicemailRecording = u'Recording Voicemail'
clsVoicemailSent = u'Voicemail is verzonden'
clsVoicemailUploading = u'Voicemail aan het uploaden'
cltIncomingP2P = u'Inkomend peer-to-peer-gesprek'
cltIncomingPSTN = u'Inkomend telefoongesprek'
cltOutgoingP2P = u'Uitgaand peer-to-peer-gesprek'
cltOutgoingPSTN = u'Uitgaand telefoongesprek'
cltUnknown = u'Onbekend'
cmeAddedMembers = u'Toegevoegde leden'
cmeCreatedChatWith = u'Chat aangemaakt met'
cmeEmoted = u'Onbekend'
cmeLeft = u'Over'
cmeSaid = u'Gezegd'
cmeSawMembers = u'Leden gezien'
cmeSetTopic = u'Topic instellen'
cmeUnknown = u'Onbekend'
cmsRead = u'Gelezen'
cmsReceived = u'Ontvangen'
cmsSending = u'Sending...'
cmsSent = u'Verzonden'
cmsUnknown = u'Onbekend'
conConnecting = u'Connecting'
conOffline = u'Offline'
conOnline = u'Online'
conPausing = u'Pauze'
conUnknown = u'Onbekend'
cusAway = u'Away'
cusDoNotDisturb = u'Do Not Disturb'
cusInvisible = u'Invisible'
cusLoggedOut = u'Logged Out'
cusNotAvailable = u'Niet beschikbaar'
cusOffline = u'Offline'
cusOnline = u'Online'
cusSkypeMe = u'SkypeMe'
cusUnknown = u'Onbekend'
cvsBothEnabled = u'Video verzenden en ontvangen'
cvsNone = u'Geen video'
cvsReceiveEnabled = u'Video ontvangen'
cvsSendEnabled = u'Video verzenden'
cvsUnknown = u''
grpAllFriends = u'Alle vrienden'
grpAllUsers = u'Alle gebruikers'
grpCustomGroup = u'Aangepast'
grpOnlineFriends = u'Online vrienden'
grpPendingAuthorizationFriends = u'Wacht op autorisatie'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Onlangs gecontacteerde gebruikers'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype-vrienden'
grpSkypeOutFriends = u'SkypeOut-vrienden'
grpUngroupedFriends = u'Ongegroepeerde vrienden'
grpUnknown = u'Onbekend'
grpUsersAuthorizedByMe = u'Door mij geautoriseerd'
grpUsersBlockedByMe = u'Door mij geblokkeerd'
grpUsersWaitingMyAuthorization = u'Wacht op mijn autorisatie'
leaAddDeclined = u'Toevoeging afgeslagen'
leaAddedNotAuthorized = u'Toegevoegde moet geautoriseerd zijn'
leaAdderNotFriend = u'Toevoeger moet vriend zijn'
leaUnknown = u'Onbekend'
leaUnsubscribe = u'Niet ingeschreven'
leaUserIncapable = u'Gebruiker incapabel'
leaUserNotFound = u'Gebruiker niet gevonden'
olsAway = u'Away'
olsDoNotDisturb = u'Do Not Disturb'
olsNotAvailable = u'Niet beschikbaar'
olsOffline = u'Offline'
olsOnline = u'Online'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Onbekend'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Female'
usexMale = u'Male'
usexUnknown = u'Onbekend'
vmrConnectError = u'Verbindingsfout'
vmrFileReadError = u'Bestandsleesfout'
vmrFileWriteError = u'Bestandsschrijffout'
vmrMiscError = u'Overige fout'
vmrNoError = u'Geen fout'
vmrNoPrivilege = u'Geen voicemailbevoegdheid'
vmrNoVoicemail = u'Voicemail bestaat niet'
vmrPlaybackError = u'Afspeelfout'
vmrRecordingError = u'Opnamefout'
vmrUnknown = u'Onbekend'
vmsBlank = u'Leeg'
vmsBuffering = u'Bezig met bufferen'
vmsDeleting = u'Bezig met verwijderen'
vmsDownloading = u'Aan het downloaden'
vmsFailed = u'Mislukt'
vmsNotDownloaded = u'Niet gedownload'
vmsPlayed = u'Afgespeeld'
vmsPlaying = u'Bezig met afspelen'
vmsRecorded = u'Opgenomen'
vmsRecording = u'Recording'
vmsUnknown = u'Onbekend'
vmsUnplayed = u'Niet afgespeeld'
vmsUploaded = u'Ge\xfcpload'
vmsUploading = u'Bezig met uploaden'
vmtCustomGreeting = u'Aangepaste begroeting'
vmtDefaultGreeting = u'Standaard begroeting'
vmtIncoming = u'Incoming'
vmtOutgoing = u'Uitgaand'
vmtUnknown = u'Onbekend'
vssAvailable = u'Beschikbaar'
vssNotAvailable = u'Niet beschikbaar'
vssPaused = u'Pauze'
vssRejected = u'Afgewezen'
vssRunning = u'Actief'
vssStarting = u'Bezig met starten'
vssStopping = u'Bezig met stoppen'
vssUnknown = u'Onbekend'
