apiAttachAvailable = u'API tilgjengelig'
apiAttachNotAvailable = u'Ikke tilgjengelig'
apiAttachPendingAuthorization = u'Venter p\xe5 \xe5 bli godkjent'
apiAttachRefused = u'Avsl\xe5tt'
apiAttachSuccess = u'Vellykket'
apiAttachUnknown = u'Ukjent'
budDeletedFriend = u'Slettet fra kontaktlisten'
budFriend = u'Venn'
budNeverBeenFriend = u'Aldri v\xe6rt i kontaktlisten'
budPendingAuthorization = u'Venter p\xe5 \xe5 bli godkjent'
budUnknown = u'Ukjent'
cfrBlockedByRecipient = u'Anrop blokkert av mottaker'
cfrMiscError = u'Diverse feil'
cfrNoCommonCodec = u'Ingen felles kodek'
cfrNoProxyFound = u'Finner ingen proxy'
cfrNotAuthorizedByRecipient = u'Gjeldende bruker er ikke godkjent av mottakeren.'
cfrRecipientNotFriend = u'Mottakeren er ikke en venn'
cfrRemoteDeviceError = u'Problem med ekstern lydenhet'
cfrSessionTerminated = u'\xd8kt avsluttet'
cfrSoundIOError = u'I/U-feil for lyd'
cfrSoundRecordingError = u'Lydinnspillingsfeil'
cfrUnknown = u'Ukjent'
cfrUserDoesNotExist = u'Bruker/telefonnummer finnes ikke'
cfrUserIsOffline = u'Hun eller han er frakoblet'
chsAllCalls = u'Foreldet dialogboks'
chsDialog = u'Dialogboks'
chsIncomingCalls = u'Flere m\xe5 godkjenne'
chsLegacyDialog = u'Foreldet dialogboks'
chsMissedCalls = u'Dialogboks'
chsMultiNeedAccept = u'Flere m\xe5 godkjenne'
chsMultiSubscribed = u'Flere abonnert'
chsOutgoingCalls = u'Flere abonnert'
chsUnknown = u'Ukjent'
chsUnsubscribed = u'Ikke abonnert'
clsBusy = u'Opptatt'
clsCancelled = u'Avbryt'
clsEarlyMedia = u'Spiller tidlige media (Early Media)'
clsFailed = u'beklager, anropet feilet!'
clsFinished = u'Avsluttet'
clsInProgress = u'Anrop p\xe5g\xe5r'
clsLocalHold = u'Lokalt parkert samtale'
clsMissed = u'Tapt anrop'
clsOnHold = u'Parkert'
clsRefused = u'Avsl\xe5tt'
clsRemoteHold = u'Eksternt parkert samtale'
clsRinging = u'Anrop'
clsRouting = u'Ruting'
clsTransferred = u'Ukjent'
clsTransferring = u'Ukjent'
clsUnknown = u'Ukjent'
clsUnplaced = u'Aldri plassert'
clsVoicemailBufferingGreeting = u'Bufrer talepostintro'
clsVoicemailCancelled = u'Talepostmelding er annullert'
clsVoicemailFailed = u'Talepost feilet'
clsVoicemailPlayingGreeting = u'Spiller av hilsen'
clsVoicemailRecording = u'Tar opp talepost'
clsVoicemailSent = u'Talepostmelding er sendt'
clsVoicemailUploading = u'Laster opp talepost'
cltIncomingP2P = u'Innkommende P2P-anrop'
cltIncomingPSTN = u'Innkommende telefonanrop'
cltOutgoingP2P = u'Utg\xe5ende P2P-anrop'
cltOutgoingPSTN = u'Utg\xe5ende telefonanrop'
cltUnknown = u'Ukjent'
cmeAddedMembers = u'Medlemmer som er lagt til'
cmeCreatedChatWith = u'Opprettet tekstsamtale med'
cmeEmoted = u'Ukjent'
cmeLeft = u'Forlatt'
cmeSaid = u'Sa'
cmeSawMembers = u'Medlemmer som ble sett'
cmeSetTopic = u'Angitt emne'
cmeUnknown = u'Ukjent'
cmsRead = u'Lest'
cmsReceived = u'Mottatt'
cmsSending = u'Sender...'
cmsSent = u'Sendt'
cmsUnknown = u'Ukjent'
conConnecting = u'Kobler til'
conOffline = u'Frakoblet'
conOnline = u'P\xe5logget'
conPausing = u'Settes i pause'
conUnknown = u'Ukjent'
cusAway = u'Borte'
cusDoNotDisturb = u'Opptatt'
cusInvisible = u'Vis som Usynlig'
cusLoggedOut = u'Frakoblet'
cusNotAvailable = u'Ikke tilgjengelig'
cusOffline = u'Frakoblet'
cusOnline = u'P\xe5logget'
cusSkypeMe = u'Skype Meg'
cusUnknown = u'Ukjent'
cvsBothEnabled = u'Videosending og -mottak'
cvsNone = u'Ingen video'
cvsReceiveEnabled = u'Videomottak'
cvsSendEnabled = u'Videosending'
cvsUnknown = u''
grpAllFriends = u'Alle venner'
grpAllUsers = u'Alle brukere'
grpCustomGroup = u'Tilpasset'
grpOnlineFriends = u'Elektroniske venner'
grpPendingAuthorizationFriends = u'Venter p\xe5 \xe5 bli godkjent'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Nylig kontaktede brukere'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype-venner'
grpSkypeOutFriends = u'SkypeOut-venner'
grpUngroupedFriends = u'Usorterte venner'
grpUnknown = u'Ukjent'
grpUsersAuthorizedByMe = u'Godkjent av meg'
grpUsersBlockedByMe = u'Blokkert av meg'
grpUsersWaitingMyAuthorization = u'Venter p\xe5 min godkjenning'
leaAddDeclined = u'Tillegging avvist'
leaAddedNotAuthorized = u'Den som legger til, m\xe5 v\xe6re autorisert'
leaAdderNotFriend = u'Den som legger til, m\xe5 v\xe6re en venn'
leaUnknown = u'Ukjent'
leaUnsubscribe = u'Ikke abonnert'
leaUserIncapable = u'Bruker forhindret'
leaUserNotFound = u'Finner ikke bruker'
olsAway = u'Borte'
olsDoNotDisturb = u'Opptatt'
olsNotAvailable = u'Ikke tilgjengelig'
olsOffline = u'Frakoblet'
olsOnline = u'P\xe5logget'
olsSkypeMe = u'Skype Meg'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Ukjent'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Kvinne'
usexMale = u'Mann'
usexUnknown = u'Ukjent'
vmrConnectError = u'Koblingsfeil'
vmrFileReadError = u'Fillesingsfeil'
vmrFileWriteError = u'Filskrivingsfeil'
vmrMiscError = u'Diverse feil'
vmrNoError = u'Ingen feil'
vmrNoPrivilege = u'Intet talepostprivilegium'
vmrNoVoicemail = u'Ingen slik talepost'
vmrPlaybackError = u'Avspillingsfeil'
vmrRecordingError = u'Innspillingsfeil'
vmrUnknown = u'Ukjent'
vmsBlank = u'Tom'
vmsBuffering = u'Bufring'
vmsDeleting = u'Sletter'
vmsDownloading = u'Laster ned'
vmsFailed = u'Mislyktes'
vmsNotDownloaded = u'Ikke nedlastet'
vmsPlayed = u'Spilt av'
vmsPlaying = u'Spiller av'
vmsRecorded = u'Innspilt'
vmsRecording = u'Tar opp talepost'
vmsUnknown = u'Ukjent'
vmsUnplayed = u'Ikke avspilt'
vmsUploaded = u'Lastet opp'
vmsUploading = u'Laster opp'
vmtCustomGreeting = u'Tilpasset hilsen'
vmtDefaultGreeting = u'Standardhilsen'
vmtIncoming = u'Innkommende talepost'
vmtOutgoing = u'Utg\xe5ende'
vmtUnknown = u'Ukjent'
vssAvailable = u'Tilgjengelig'
vssNotAvailable = u'Ikke tilgjengelig'
vssPaused = u'Satt i pause'
vssRejected = u'Avvist'
vssRunning = u'Kj\xf8rer'
vssStarting = u'Starter'
vssStopping = u'Stanser'
vssUnknown = u'Ukjent'
