apiAttachAvailable = u'API dispon\xedvel'
apiAttachNotAvailable = u'N\xe3o dispon\xedvel'
apiAttachPendingAuthorization = u'Autoriza\xe7\xe3o pendente'
apiAttachRefused = u'Recusado'
apiAttachSuccess = u'Sucesso'
apiAttachUnknown = u'Desconhecido'
budDeletedFriend = u'Apagado da Lista de Amigos'
budFriend = u'Amigo'
budNeverBeenFriend = u'Nunca esteve na Lista de Amigos'
budPendingAuthorization = u'Autoriza\xe7\xe3o pendente'
budUnknown = u'Desconhecido'
cfrBlockedByRecipient = u'Chamada bloqueada pelo destinat\xe1rio'
cfrMiscError = u'Erro diverso'
cfrNoCommonCodec = u'Nenhum codec comum'
cfrNoProxyFound = u'Proxy n\xe3o encontrado'
cfrNotAuthorizedByRecipient = u'O utilizador actual n\xe3o est\xe1 autorizado pelo destinat\xe1rio'
cfrRecipientNotFriend = u'Destinat\xe1rio n\xe3o \xe9 um amigo'
cfrRemoteDeviceError = u'Problema com dispositivo de som remoto'
cfrSessionTerminated = u'Sess\xe3o encerrada'
cfrSoundIOError = u'Erro de I/O de som'
cfrSoundRecordingError = u'Erro de grava\xe7\xe3o de voz'
cfrUnknown = u'Desconhecido'
cfrUserDoesNotExist = u'O utilizador/n\xfamero de telefone n\xe3o existe'
cfrUserIsOffline = u'Ela/ele est\xe1 offline'
chsAllCalls = u'Di\xe1logo antigo'
chsDialog = u'Di\xe1logo'
chsIncomingCalls = u'Multi Precisa Aceitar'
chsLegacyDialog = u'Di\xe1logo antigo'
chsMissedCalls = u'Di\xe1logo'
chsMultiNeedAccept = u'Multi Precisa Aceitar'
chsMultiSubscribed = u'Multi Registados'
chsOutgoingCalls = u'Multi Registados'
chsUnknown = u'Desconhecido'
chsUnsubscribed = u'Assinatura eliminada'
clsBusy = u'Ocupado'
clsCancelled = u'Cancelado'
clsEarlyMedia = u'Tocar os dados iniciais (Early Media)'
clsFailed = u'Desculpe, falha na chamada!'
clsFinished = u'Terminado'
clsInProgress = u'Chamada em curso'
clsLocalHold = u'Em espera local'
clsMissed = u'Chamada Perdida'
clsOnHold = u'Em espera'
clsRefused = u'Recusado'
clsRemoteHold = u'Em espera remota'
clsRinging = u'chamadas'
clsRouting = u'A encaminhar'
clsTransferred = u'Desconhecido'
clsTransferring = u'Desconhecido'
clsUnknown = u'Desconhecido'
clsUnplaced = u'Nunca foi adicionado'
clsVoicemailBufferingGreeting = u'A colocar sauda\xe7\xe3o na mem\xf3ria interm\xe9dia'
clsVoicemailCancelled = u'As mensagens (voicemail) foram canceladas'
clsVoicemailFailed = u'Falha na Mensagem de Voz'
clsVoicemailPlayingGreeting = u'A tocar Sauda\xe7\xe3o'
clsVoicemailRecording = u'A gravar Mensagem de Voz'
clsVoicemailSent = u'As mensagens (voicemail) foram enviadas'
clsVoicemailUploading = u'A carregar as mensagens (Voicemail)'
cltIncomingP2P = u'A receber chamada peer-to-peer'
cltIncomingPSTN = u'A receber chamada de voz'
cltOutgoingP2P = u'A efectuar chamada peer-to-peer'
cltOutgoingPSTN = u'A efectuar chamada telef\xf3nica'
cltUnknown = u'Desconhecido'
cmeAddedMembers = u'Membros adicionados'
cmeCreatedChatWith = u'Chat criado com'
cmeEmoted = u'Desconhecido'
cmeLeft = u'Saiu'
cmeSaid = u'Disse'
cmeSawMembers = u'Membros vistos'
cmeSetTopic = u'Definir t\xf3pico'
cmeUnknown = u'Desconhecido'
cmsRead = u'Ler'
cmsReceived = u'Recebido'
cmsSending = u'A enviar...'
cmsSent = u'Enviado'
cmsUnknown = u'Desconhecido'
conConnecting = u'A ligar'
conOffline = u'Offline'
conOnline = u'Online'
conPausing = u'A colocar em pausa'
conUnknown = u'Desconhecido'
cusAway = u'Ausente'
cusDoNotDisturb = u'Ocupado'
cusInvisible = u'Invis\xedvel'
cusLoggedOut = u'Offline'
cusNotAvailable = u'N\xe3o dispon\xedvel'
cusOffline = u'Offline'
cusOnline = u'Online'
cusSkypeMe = u'Skype Me'
cusUnknown = u'Desconhecido'
cvsBothEnabled = u'A enviar e receber v\xeddeo'
cvsNone = u'V\xeddeo n\xe3o dispon\xedvel'
cvsReceiveEnabled = u'A receber v\xeddeo'
cvsSendEnabled = u'A enviar v\xeddeo'
cvsUnknown = u''
grpAllFriends = u'Todos os amigos'
grpAllUsers = u'Todos os utilizadores'
grpCustomGroup = u'Personalizado'
grpOnlineFriends = u'Amigos on-line'
grpPendingAuthorizationFriends = u'Autoriza\xe7\xe3o pendente'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Utilizadores contactados recentemente'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Amigos Skype'
grpSkypeOutFriends = u'Amigos SkypeOut'
grpUngroupedFriends = u'Amigos n\xe3o organizados em grupos'
grpUnknown = u'Desconhecido'
grpUsersAuthorizedByMe = u'Autorizado por mim'
grpUsersBlockedByMe = u'Bloqueado por mim'
grpUsersWaitingMyAuthorization = u'\xc0 espera da minha autoriza\xe7\xe3o'
leaAddDeclined = u'Adicionamento recusado'
leaAddedNotAuthorized = u'O adicionado deve ser autorizado'
leaAdderNotFriend = u'Quem adiciona deve ser um amigo'
leaUnknown = u'Desconhecido'
leaUnsubscribe = u'Assinatura eliminada'
leaUserIncapable = u'Utilizador n\xe3o habilitado'
leaUserNotFound = u'Utilizador n\xe3o encontrado'
olsAway = u'Ausente'
olsDoNotDisturb = u'Ocupado'
olsNotAvailable = u'N\xe3o dispon\xedvel'
olsOffline = u'Offline'
olsOnline = u'Online'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Desconhecido'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Feminino'
usexMale = u'Masculino'
usexUnknown = u'Desconhecido'
vmrConnectError = u'Erro de liga\xe7\xe3o'
vmrFileReadError = u'Erro na leitura do ficheiro'
vmrFileWriteError = u'Erro a escrever ficheiro'
vmrMiscError = u'Erro diverso'
vmrNoError = u'N\xe3o h\xe1 erro'
vmrNoPrivilege = u'Sem privil\xe9gio de Voicemail'
vmrNoVoicemail = u'N\xe3o existe tal Voicemail'
vmrPlaybackError = u'Erro de reprodu\xe7\xe3o'
vmrRecordingError = u'Erro a gravar'
vmrUnknown = u'Desconhecido'
vmsBlank = u'Em branco'
vmsBuffering = u'A colocar na mem\xf3ria interm\xe9dia'
vmsDeleting = u'A apagar'
vmsDownloading = u'A transferir'
vmsFailed = u'Falhou'
vmsNotDownloaded = u'N\xe3o transferido'
vmsPlayed = u'Reproduzido'
vmsPlaying = u'A reproduzir'
vmsRecorded = u'Gravado'
vmsRecording = u'A gravar Mensagem de Voz'
vmsUnknown = u'Desconhecido'
vmsUnplayed = u'N\xe3o ouvido'
vmsUploaded = u'Carregado'
vmsUploading = u'A carregar'
vmtCustomGreeting = u'Sauda\xe7\xe3o personalizada'
vmtDefaultGreeting = u'Sauda\xe7\xe3o predefinida'
vmtIncoming = u'Receber Voice Mail'
vmtOutgoing = u'De sa\xedda'
vmtUnknown = u'Desconhecido'
vssAvailable = u'Dispon\xedvel'
vssNotAvailable = u'N\xe3o dispon\xedvel'
vssPaused = u'Em pausa'
vssRejected = u'Rejeitada'
vssRunning = u'Em curso'
vssStarting = u'A iniciar'
vssStopping = u'A terminar'
vssUnknown = u'Desconhecido'
