apiAttachAvailable = u'API \uc0ac\uc6a9\uac00\ub2a5'
apiAttachNotAvailable = u'\uc678\ucd9c \uc911'
apiAttachPendingAuthorization = u'\uc2b9\uc778 \ubcf4\ub958 \uc911'
apiAttachRefused = u'\ud1b5\ud654 \uac70\ubd80'
apiAttachSuccess = u'\uc131\uacf5'
apiAttachUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
budDeletedFriend = u'\uce5c\uad6c\ubaa9\ub85d\uc5d0\uc11c \uc0ad\uc81c\ub428'
budFriend = u'\uce5c\uad6c'
budNeverBeenFriend = u'\uce5c\uad6c\ubaa9\ub85d\uc5d0 \uc785\ub825\ud55c \uc801\uc774 \uc5c6\uc74c'
budPendingAuthorization = u'\uc2b9\uc778 \ubcf4\ub958 \uc911'
budUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
cfrBlockedByRecipient = u'\uc218\uc2e0\uc790\uc5d0 \uc758\ud574 \ud1b5\ud654 \ucc28\ub2e8'
cfrMiscError = u'\uae30\ud0c0 \uc624\ub958'
cfrNoCommonCodec = u'\uc77c\ubc18 \ucf54\ub371 \uc5c6\uc74c'
cfrNoProxyFound = u'\ubc1c\uacac\ub41c \ud504\ub85d\uc2dc \uc5c6\uc74c'
cfrNotAuthorizedByRecipient = u'\ud604 \uc0ac\uc6a9\uc790\ub97c \uc218\uc2e0\uc790\uac00 \uc2b9\uc778\ud558\uc9c0 \uc54a\uc558\uc2b5\ub2c8\ub2e4.'
cfrRecipientNotFriend = u'\uc218\uc2e0\uc790\uac00 \uce5c\uad6c\uac00 \uc544\ub2d8'
cfrRemoteDeviceError = u'\uc6d0\uaca9 \uc0ac\uc6b4\ub4dc IO \uc624\ub958'
cfrSessionTerminated = u'\uc138\uc158 \uc885\ub8cc'
cfrSoundIOError = u'\uc0ac\uc6b4\ub4dc I/O \uc624\ub958'
cfrSoundRecordingError = u'\uc0ac\uc6b4\ub4dc \ub179\uc74c \uc624\ub958'
cfrUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
cfrUserDoesNotExist = u'\uc0ac\uc6a9\uc790/\uc804\ud654\ubc88\ud638\uac00 \uc874\uc7ac\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4'
cfrUserIsOffline = u'\uc0c1\ub300\ubc29\uc774 \uc624\ud504\ub77c\uc778 \uc0c1\ud0dc\uc785\ub2c8\ub2e4'
chsAllCalls = u'\ub808\uac70\uc2dc \ub2e4\uc774\uc5bc\ub85c\uadf8'
chsDialog = u'\ub2e4\uc774\uc5bc\ub85c\uadf8'
chsIncomingCalls = u'\ub2e4\uc218\uac00 \uc218\ub77d\uc744 \uc694\ud568'
chsLegacyDialog = u'\ub808\uac70\uc2dc \ub2e4\uc774\uc5bc\ub85c\uadf8'
chsMissedCalls = u'\ub2e4\uc774\uc5bc\ub85c\uadf8'
chsMultiNeedAccept = u'\ub2e4\uc218\uac00 \uc218\ub77d\uc744 \uc694\ud568'
chsMultiSubscribed = u'\ub2e4\uc218\uac00 \uac00\uc785\ud568'
chsOutgoingCalls = u'\ub2e4\uc218\uac00 \uac00\uc785\ud568'
chsUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
chsUnsubscribed = u'\ubbf8\uac00\uc785'
clsBusy = u'\ud1b5\ud654 \uc911'
clsCancelled = u'\ucde8\uc18c\ub418\uc5c8\uc74c'
clsEarlyMedia = u'\ucd08\uae30 \ubbf8\ub514\uc5b4(Early Media) \uc7ac\uc0dd\uc911'
clsFailed = u'\uc8c4\uc1a1\ud569\ub2c8\ub2e4. \ud1b5\ud654\uac00 \uc2e4\ud328\ud588\uc2b5\ub2c8\ub2e4!'
clsFinished = u'\uc885\ub8cc'
clsInProgress = u'\ud1b5\ud654 \uc9c4\ud589 \uc911'
clsLocalHold = u'\ud604 \uc0ac\uc6a9\uc790\uac00 \ud1b5\ud654\ubcf4\ub958\ud568'
clsMissed = u'\ud1b5\ud654 \ubabb\ubc1b\uc74c'
clsOnHold = u'\ubcf4\ub958'
clsRefused = u'\ud1b5\ud654 \uac70\ubd80'
clsRemoteHold = u'\uc6d0\uaca9 \ubcf4\ub958\ud568'
clsRinging = u'\uc804\ud654\uac78\uae30'
clsRouting = u'\ub77c\uc6b0\ud305'
clsTransferred = u'\uc54c \uc218 \uc5c6\uc74c'
clsTransferring = u'\uc54c \uc218 \uc5c6\uc74c'
clsUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
clsUnplaced = u'\uc804\ud654\uac00 \uac78\ub9ac\uc9c0 \uc54a\uc74c'
clsVoicemailBufferingGreeting = u'\uc778\uc0ac\ub9d0 \ubc84\ud37c\ub9c1 \uc911'
clsVoicemailCancelled = u'\ubcf4\uc774\uc2a4\uba54\uc77c\uc774 \ucde8\uc18c\ub418\uc5c8\uc2b5\ub2c8\ub2e4'
clsVoicemailFailed = u'\ubcf4\uc774\uc2a4\uba54\uc77c \uc2e4\ud328'
clsVoicemailPlayingGreeting = u'\uc778\uc0ac\ub9d0 \ud50c\ub808\uc774 \uc911'
clsVoicemailRecording = u'\ubcf4\uc774\uc2a4\uba54\uc77c \ub179\uc74c\uc911'
clsVoicemailSent = u'\ubcf4\uc774\uc2a4\uba54\uc77c\uc774 \uc804\uc1a1\ub418\uc5c8\uc2b5\ub2c8\ub2e4'
clsVoicemailUploading = u'\ubcf4\uc774\uc2a4\uba54\uc77c \uc5c5\ub85c\ub4dc \uc911'
cltIncomingP2P = u'\uc218\uc2e0 \ud53c\uc5b4-\ud22c-\ud53c\uc5b4 \ud1b5\ud654'
cltIncomingPSTN = u'\uc218\uc2e0 \uc804\ud654\ud1b5\ud654'
cltOutgoingP2P = u'\ubc1c\uc2e0 \ud53c\uc5b4-\ud22c-\ud53c\uc5b4 \ud1b5\ud654'
cltOutgoingPSTN = u'\ubc1c\uc2e0 \uc804\ud654\ud1b5\ud654'
cltUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
cmeAddedMembers = u'\ud68c\uc6d0\uc744 \ucd94\uac00\ud588\uc74c'
cmeCreatedChatWith = u'\ub2e4\uc74c \uc0c1\ub300\uc640 \ucc44\ud305 \ud615\uc131'
cmeEmoted = u'\uc54c \uc218 \uc5c6\uc74c'
cmeLeft = u'\ub5a0\ub0a8'
cmeSaid = u'\ub9d0\ud55c \ub0b4\uc6a9'
cmeSawMembers = u'\ud68c\uc6d0\uc744 \ubcf4\uc558\uc74c'
cmeSetTopic = u'\uc8fc\uc81c \uc124\uc815'
cmeUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
cmsRead = u'\uc77d\uc74c'
cmsReceived = u'\uc218\uc2e0'
cmsSending = u'\ubcf4\ub0b4\ub294 \uc911...'
cmsSent = u'\uc804\uc1a1\uc644\ub8cc'
cmsUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
conConnecting = u'\uc5f0\uacb0 \uc911'
conOffline = u'\uc624\ud504\ub77c\uc778'
conOnline = u'\uc628\ub77c\uc778'
conPausing = u'\uc77c\uc2dc \uc911\uc9c0'
conUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
cusAway = u'\uc790\ub9ac \ube44\uc6c0'
cusDoNotDisturb = u'\ub2e4\ub978 \uc6a9\ubb34\uc911'
cusInvisible = u'\ud22c\uba85\uc778\uac04'
cusLoggedOut = u'\uc624\ud504\ub77c\uc778'
cusNotAvailable = u'\uc678\ucd9c \uc911'
cusOffline = u'\uc624\ud504\ub77c\uc778'
cusOnline = u'\uc628\ub77c\uc778'
cusSkypeMe = u'Skype Me'
cusUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
cvsBothEnabled = u'\ube44\ub514\uc624 \uc804\uc1a1 \ubc0f \uc218\uc2e0'
cvsNone = u'\ube44\ub514\uc624 \uc5c6\uc74c'
cvsReceiveEnabled = u'\ube44\ub514\uc624 \uc218\uc2e0'
cvsSendEnabled = u'\ube44\ub514\uc624 \uc804\uc1a1'
cvsUnknown = u''
grpAllFriends = u'\ubaa8\ub4e0 \uce5c\uad6c'
grpAllUsers = u'\ubaa8\ub4e0 \uc0ac\uc6a9\uc790'
grpCustomGroup = u'\ub9de\ucda4'
grpOnlineFriends = u'\uc628\ub77c\uc778 \uce5c\uad6c\ub4e4'
grpPendingAuthorizationFriends = u'\uc2b9\uc778 \ubcf4\ub958 \uc911'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'\ucd5c\uadfc\uc5d0 \uc5f0\ub77d\ud55c \uc0ac\uc6a9\uc790'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype \uce5c\uad6c\ub4e4'
grpSkypeOutFriends = u'SkypeOut \uce5c\uad6c\ub4e4'
grpUngroupedFriends = u'\uadf8\ub8f9\uc5d0 \uc18d\ud558\uc9c0 \uc54a\uc740 \uce5c\uad6c\ub4e4'
grpUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
grpUsersAuthorizedByMe = u'\ub0b4\uac00 \uc2b9\uc778\ud55c \uc0ac\uc6a9\uc790'
grpUsersBlockedByMe = u'\ub0b4\uac00 \ucc28\ub2e8\ud55c \uc0ac\uc6a9\uc790'
grpUsersWaitingMyAuthorization = u'\ub0b4 \uc2b9\uc778\uc744 \uae30\ub2e4\ub9ac\ub294 \uc0ac\uc6a9\uc790'
leaAddDeclined = u'\ucd94\uac00\uac00 \uac70\ubd80\ub428'
leaAddedNotAuthorized = u'\ucd94\uac00\ub418\ub294 \ub300\uc0c1\uc774 \ubc18\ub4dc\uc2dc \uc2b9\uc778\ub418\uc5b4\uc57c \ud568'
leaAdderNotFriend = u'\ucd94\uac00\ud558\ub294 \uc0ac\ub78c\uc774 \ubc18\ub4dc\uc2dc \uce5c\uad6c\uc5ec\uc57c \ud568'
leaUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
leaUnsubscribe = u'\ubbf8\uac00\uc785'
leaUserIncapable = u'\uc0ac\uc6a9\uc790 \uc0ac\uc6a9\ubd88\ub2a5'
leaUserNotFound = u'\uc0ac\uc6a9\uc790\ub97c \ucc3e\uc9c0 \ubabb\ud568'
olsAway = u'\uc790\ub9ac \ube44\uc6c0'
olsDoNotDisturb = u'\ub2e4\ub978 \uc6a9\ubb34\uc911'
olsNotAvailable = u'\uc678\ucd9c \uc911'
olsOffline = u'\uc624\ud504\ub77c\uc778'
olsOnline = u'\uc628\ub77c\uc778'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'\uc5ec'
usexMale = u'\ub0a8'
usexUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
vmrConnectError = u'\uc5f0\uacb0 \uc624\ub958'
vmrFileReadError = u'\ud30c\uc77c \uc77d\uae30 \uc624\ub958'
vmrFileWriteError = u'\ud30c\uc77c \uc4f0\uae30 \uc624\ub958'
vmrMiscError = u'\uae30\ud0c0 \uc624\ub958'
vmrNoError = u'\uc624\ub958 \uc5c6\uc74c'
vmrNoPrivilege = u'\ubcf4\uc774\uc2a4\uba54\uc77c \uc6b0\uc120\uad8c \uc5c6\uc74c'
vmrNoVoicemail = u'\uadf8\ub7ec\ud55c \ubcf4\uc774\uc2a4\uba54\uc77c\uc774 \uc5c6\uc74c'
vmrPlaybackError = u'\uc7ac\uc0dd \uc624\ub958'
vmrRecordingError = u'\ub179\uc74c \uc624\ub958'
vmrUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
vmsBlank = u'\uba54\uc2dc\uc9c0 \uc5c6\uc74c'
vmsBuffering = u'\ubc84\ud37c\ub9c1'
vmsDeleting = u'\uc0ad\uc81c \uc911'
vmsDownloading = u'\ub2e4\uc6b4\ub85c\ub4dc \uc911'
vmsFailed = u'\uc2e4\ud328\ud568'
vmsNotDownloaded = u'\ub2e4\uc6b4\ub85c\ub4dc \ub418\uc9c0 \uc54a\uc74c'
vmsPlayed = u'\ud50c\ub808\uc774 \ud568'
vmsPlaying = u'\ud50c\ub808\uc774 \uc911'
vmsRecorded = u'\ub179\uc74c\ub428'
vmsRecording = u'\ubcf4\uc774\uc2a4\uba54\uc77c \ub179\uc74c\uc911'
vmsUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
vmsUnplayed = u'\ud50c\ub808\uc774 \uc548\ub428'
vmsUploaded = u'\uc5c5\ub85c\ub4dc\ub428'
vmsUploading = u'\uc5c5\ub85c\ub4dc\uc911'
vmtCustomGreeting = u'\ub9de\ucda4 \uc778\uc0ac\ub9d0'
vmtDefaultGreeting = u'\uc9c0\uc815 \uc778\uc0ac\ub9d0'
vmtIncoming = u'\ubc1b\uc740 \ubcf4\uc774\uc2a4\uba54\uc77c'
vmtOutgoing = u'\ubc1c\uc2e0'
vmtUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
vssAvailable = u'\uc0ac\uc6a9\uac00\ub2a5'
vssNotAvailable = u'\uc678\ucd9c \uc911'
vssPaused = u'\uc77c\uc2dc\uc815\uc9c0'
vssRejected = u'\uac70\ubd80\ub428'
vssRunning = u'\uc791\ub3d9 \uc911'
vssStarting = u'\uc2dc\uc791'
vssStopping = u'\uc815\uc9c0 \uc911'
vssUnknown = u'\uc54c \uc218 \uc5c6\uc74c'
