apiAttachAvailable = u'Leitud'
apiAttachNotAvailable = u'Kadunud'
apiAttachPendingAuthorization = u'Autoriseerimine'
apiAttachRefused = u'Keeldumine'
apiAttachSuccess = u'\xdchendatud'
apiAttachUnknown = u'M\xe4\xe4ramata'
budDeletedFriend = u'Kustutatud S\xf5ber'
budFriend = u'S\xf5ber'
budNeverBeenFriend = u'Pole Olnud S\xf5ber'
budPendingAuthorization = u'Ootab Autoriseerimist'
budUnknown = u'M\xe4\xe4ramata'
cfrBlockedByRecipient = u'Blokeeritud vastuv\xf5tja poolt'
cfrMiscError = u'M\xe4\xe4ramata viga'
cfrNoCommonCodec = u'pole \xfchist kodekit'
cfrNoProxyFound = u'Ei leitud l\xfc\xfcsi'
cfrNotAuthorizedByRecipient = u'Helistaja pole autoriseeritud'
cfrRecipientNotFriend = u'K\xf5ne vastuv\xf5tja pole s\xf5ber'
cfrRemoteDeviceError = u'Probleem teise poole heliseadmega'
cfrSessionTerminated = u'\xfchendus katkestatud'
cfrSoundIOError = u'Heli viga'
cfrSoundRecordingError = u'Helisalvestuse viga'
cfrUnknown = u'M\xe4\xe4ramata'
cfrUserDoesNotExist = u'Kasutajat v\xf5i numbrit pole olemas'
cfrUserIsOffline = u"Ta ei ole Skype'i sisse logitud"
chsAllCalls = u'Vana Dialoog'
chsDialog = u'Dialoog'
chsIncomingCalls = u'Multiaksept'
chsLegacyDialog = u'Vana Dialoog'
chsMissedCalls = u'Dialoog'
chsMultiNeedAccept = u'Multiaksept'
chsMultiSubscribed = u'Multiteenus'
chsOutgoingCalls = u'Multiteenus'
chsUnknown = u'M\xe4\xe4ramata'
chsUnsubscribed = u'Tellimata'
clsBusy = u'H\xf5ivatud'
clsCancelled = u'Katkestatud'
clsEarlyMedia = u'M\xe4ngib Muusikat'
clsFailed = u'K\xf5ne kahjuks eba\xf5nnestus!'
clsFinished = u'L\xf5petatud'
clsInProgress = u'Aktiivne k\xf5ne'
clsLocalHold = u'Peatatud Lokaalselt'
clsMissed = u'Vastamata k\xf5ne'
clsOnHold = u'Ootel'
clsRefused = u'Keeldutud'
clsRemoteHold = u'Peatatud Eemal'
clsRinging = u'Heliseb'
clsRouting = u'Ruutimine'
clsTransferred = u'M\xe4\xe4ramata'
clsTransferring = u'M\xe4\xe4ramata'
clsUnknown = u'M\xe4\xe4ramata'
clsUnplaced = u'Pole Helistatud'
clsVoicemailBufferingGreeting = u'Tervituse Laadimine'
clsVoicemailCancelled = u'Katkestatud'
clsVoicemailFailed = u'K\xd5nepost eba\xf5nnestus'
clsVoicemailPlayingGreeting = u'Tervituse M\xe4ngimine'
clsVoicemailRecording = u'K\xf5neposti salvestamine'
clsVoicemailSent = u'Saadetud'
clsVoicemailUploading = u'\xdcleslaadimine'
cltIncomingP2P = u'P2P Sisse'
cltIncomingPSTN = u'PSTN Sisse'
cltOutgoingP2P = u'P2P V\xe4lja'
cltOutgoingPSTN = u'PSTN V\xe4lja'
cltUnknown = u'M\xe4\xe4ramata'
cmeAddedMembers = u'Lisas Osalejad'
cmeCreatedChatWith = u'Tegi Jututoa'
cmeEmoted = u'M\xe4\xe4ramata'
cmeLeft = u'Lahkus'
cmeSaid = u'\xdctles'
cmeSawMembers = u'N\xe4gi Osalejaid'
cmeSetTopic = u'Tegi Pealkirja'
cmeUnknown = u'M\xe4\xe4ramata'
cmsRead = u'Loetud'
cmsReceived = u'Vastuv\xf5etud'
cmsSending = u'Saadab...'
cmsSent = u'Saadetud'
cmsUnknown = u'M\xe4\xe4ramata'
conConnecting = u'\xdchendan'
conOffline = u'V\xe4ljas'
conOnline = u'Sees'
conPausing = u'Paus'
conUnknown = u'M\xe4\xe4ramata'
cusAway = u'Eemal'
cusDoNotDisturb = u'H\xf5ivatud'
cusInvisible = u'N\xe4htamatu'
cusLoggedOut = u'V\xe4ljas'
cusNotAvailable = u'Kaua eemal'
cusOffline = u'V\xe4ljas'
cusOnline = u'Sees'
cusSkypeMe = u'Skype Me'
cusUnknown = u'M\xe4\xe4ramata'
cvsBothEnabled = u'Video Saatmine ja Vastuv\xf5tmine'
cvsNone = u'Video Puudub'
cvsReceiveEnabled = u'Video Vastuv\xf5tmine'
cvsSendEnabled = u'Video Saatmine'
cvsUnknown = u''
grpAllFriends = u'K\xf5ik S\xf5brad'
grpAllUsers = u'K\xf5ik Kasutajad'
grpCustomGroup = u'Kasutaja Grupp'
grpOnlineFriends = u'\xdchendatud S\xf5brad'
grpPendingAuthorizationFriends = u'Autoriseerimise Ootel'
grpProposedSharedGroup = u'Pakutud Jagatud Grupp'
grpRecentlyContactedUsers = u'Hiljutised S\xf5brad'
grpSharedGroup = u'Jagatud Grupp'
grpSkypeFriends = u'Skype S\xf5brad'
grpSkypeOutFriends = u'SkypeOut S\xf5brad'
grpUngroupedFriends = u'Grupeerimata'
grpUnknown = u'M\xe4\xe4ramata'
grpUsersAuthorizedByMe = u'Minu Poolt Autoriseeritud'
grpUsersBlockedByMe = u'Minu Poolt Blokeeritud'
grpUsersWaitingMyAuthorization = u'Ootavad Minu Luba'
leaAddDeclined = u'Tagasil\xfckatud'
leaAddedNotAuthorized = u'Pole Autoriseeritud'
leaAdderNotFriend = u'Pole S\xf5ber'
leaUnknown = u'M\xe4\xe4ramata'
leaUnsubscribe = u'Eemaldus'
leaUserIncapable = u'Kasutaja V\xf5imalused Piiratud'
leaUserNotFound = u'Kasutajat Ei Leitud'
olsAway = u'Eemal'
olsDoNotDisturb = u'H\xf5ivatud'
olsNotAvailable = u'Kaua eemal'
olsOffline = u'V\xe4ljas'
olsOnline = u'Sees'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'M\xe4\xe4ramata'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Naine'
usexMale = u'Mees'
usexUnknown = u'M\xe4\xe4ramata'
vmrConnectError = u'\xdchenduse Viga'
vmrFileReadError = u'Viga Lugemisel'
vmrFileWriteError = u'Viga Kirjutamisel'
vmrMiscError = u'M\xe4\xe4ramata Viga'
vmrNoError = u'Korras'
vmrNoPrivilege = u'Pole K\xf5neposti Privileegi'
vmrNoVoicemail = u'Pole Sellist K\xf5neposti'
vmrPlaybackError = u'Viga Esitamisel'
vmrRecordingError = u'Viga Salvestamisel'
vmrUnknown = u'M\xe4\xe4ramata'
vmsBlank = u'T\xfchi'
vmsBuffering = u'Kogumine'
vmsDeleting = u'Kustutamine'
vmsDownloading = u'Allalaadimine'
vmsFailed = u'Eba\xf5nnestus'
vmsNotDownloaded = u'Pole Laaditud'
vmsPlayed = u'Esitatud'
vmsPlaying = u'Esitamine'
vmsRecorded = u'Salvestatud'
vmsRecording = u'K\xf5neposti salvestamine'
vmsUnknown = u'M\xe4\xe4ramata'
vmsUnplayed = u'M\xe4ngimata'
vmsUploaded = u'\xdcleslaaditud'
vmsUploading = u'\xdcleslaadimine'
vmtCustomGreeting = u'Kasutaja Tervitus'
vmtDefaultGreeting = u'Vaikimisi Tervitus'
vmtIncoming = u'sissetulev k\xf5nepost'
vmtOutgoing = u'V\xe4ljaminev'
vmtUnknown = u'M\xe4\xe4ramata'
vssAvailable = u'Olemas'
vssNotAvailable = u'Puudub'
vssPaused = u'Peatatud'
vssRejected = u'Tagasil\xfckatud'
vssRunning = u'Kestev'
vssStarting = u'Algab'
vssStopping = u'Peatamine'
vssUnknown = u'M\xe4\xe4ramata'
