apiAttachAvailable = u'API tillg\xe4ngligt'
apiAttachNotAvailable = u'Inte tillg\xe4ngligt'
apiAttachPendingAuthorization = u'Godk\xe4nnande avvaktas'
apiAttachRefused = u'Nekades'
apiAttachSuccess = u'Det lyckades'
apiAttachUnknown = u'Ok\xe4nd'
budDeletedFriend = u'Borttagen fr\xe5n kontaktlistan'
budFriend = u'V\xe4n'
budNeverBeenFriend = u'Aldrig varit i kontaktlistan'
budPendingAuthorization = u'Godk\xe4nnande avvaktas'
budUnknown = u'Ok\xe4nd'
cfrBlockedByRecipient = u'Samtalet blockerades av mottagaren'
cfrMiscError = u'Div fel'
cfrNoCommonCodec = u'Gemensam codec saknas'
cfrNoProxyFound = u'Mellanserver finns inte'
cfrNotAuthorizedByRecipient = u'Aktuell anv\xe4ndare inte godk\xe4nd av mottagaren'
cfrRecipientNotFriend = u'Mottagaren ej en v\xe4n'
cfrRemoteDeviceError = u'Det har uppst\xe5tt problem med motpartens ljudenhet'
cfrSessionTerminated = u'Sessionen avslutad'
cfrSoundIOError = u'I/O-fel p\xe5 ljudet'
cfrSoundRecordingError = u'Ljudinspelningsfel'
cfrUnknown = u'Ok\xe4nd'
cfrUserDoesNotExist = u'Anv\xe4ndaren/telefonnumret finns inte'
cfrUserIsOffline = u'Anv\xe4ndaren \xe4r offline'
chsAllCalls = u'Legacy-dialog'
chsDialog = u'Dialog'
chsIncomingCalls = u'Kr\xe4ver multi-godk\xe4nnande'
chsLegacyDialog = u'Legacy-dialog'
chsMissedCalls = u'Dialog'
chsMultiNeedAccept = u'Kr\xe4ver multi-godk\xe4nnande'
chsMultiSubscribed = u'Multi-abonnerade'
chsOutgoingCalls = u'Multi-abonnerade'
chsUnknown = u'Ok\xe4nd'
chsUnsubscribed = u'Avabonnerad'
clsBusy = u'Upptaget'
clsCancelled = u'Avbruten'
clsEarlyMedia = u'Spelar Early Media'
clsFailed = u'Samtalet kunde inte kopplas'
clsFinished = u'Avslutat'
clsInProgress = u'P\xe5g\xe5ende samtal'
clsLocalHold = u'Lokalt parkerat samtal'
clsMissed = u'missat samtal'
clsOnHold = u'Parkerad'
clsRefused = u'Nekades'
clsRemoteHold = u'Fj\xe4rrparkerat samtal'
clsRinging = u'pratat'
clsRouting = u'Routar'
clsTransferred = u'Ok\xe4nd'
clsTransferring = u'Ok\xe4nd'
clsUnknown = u'Ok\xe4nd'
clsUnplaced = u'Inte uppringt'
clsVoicemailBufferingGreeting = u'Buffrar h\xe4lsningen'
clsVoicemailCancelled = u'R\xf6stmeddelandet avbr\xf6ts'
clsVoicemailFailed = u'R\xf6stmeddelandet misslyckades'
clsVoicemailPlayingGreeting = u'Spelar h\xe4lsningen'
clsVoicemailRecording = u'Spelar in r\xf6stmeddelande'
clsVoicemailSent = u'R\xf6stmeddelandet skickades'
clsVoicemailUploading = u'Laddar upp r\xf6stmeddelande'
cltIncomingP2P = u'Inkommande P2P-samtal'
cltIncomingPSTN = u'Inkommande telefonsamtal'
cltOutgoingP2P = u'Utg\xe5ende P2P-samtal'
cltOutgoingPSTN = u'Utg\xe5ende telefonsamtal'
cltUnknown = u'Ok\xe4nd'
cmeAddedMembers = u'Medlemmar lades till'
cmeCreatedChatWith = u'Startade chatt med'
cmeEmoted = u'Ok\xe4nd'
cmeLeft = u'L\xe4mnade'
cmeSaid = u'Redan sagt'
cmeSawMembers = u'S\xe5g medlemmar'
cmeSetTopic = u'Ange \xe4mne'
cmeUnknown = u'Ok\xe4nd'
cmsRead = u'L\xe4stes'
cmsReceived = u'Togs emot'
cmsSending = u'S\xe4nder...'
cmsSent = u'Skickades'
cmsUnknown = u'Ok\xe4nd'
conConnecting = u'Ansluter...'
conOffline = u'Offline'
conOnline = u'Online'
conPausing = u'Pauserar'
conUnknown = u'Ok\xe4nd'
cusAway = u'Tillf\xe4lligt borta'
cusDoNotDisturb = u'St\xf6r ej'
cusInvisible = u'Osynlig'
cusLoggedOut = u'Offline'
cusNotAvailable = u'Inte tillg\xe4ngligt'
cusOffline = u'Offline'
cusOnline = u'Online'
cusSkypeMe = u'Skype Me'
cusUnknown = u'Ok\xe4nd'
cvsBothEnabled = u'Skickar och tar emot video'
cvsNone = u'Ingen video'
cvsReceiveEnabled = u'Tar emot video'
cvsSendEnabled = u'Skickar video'
cvsUnknown = u''
grpAllFriends = u'Alla kontakter'
grpAllUsers = u'Alla anv\xe4ndare'
grpCustomGroup = u'S\xe4rskild'
grpOnlineFriends = u'Online-v\xe4nner'
grpPendingAuthorizationFriends = u'Godk\xe4nnande avvaktas'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Nyligen kontaktade anv\xe4ndare'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype-kontakter'
grpSkypeOutFriends = u'SkypeOut-kontakter'
grpUngroupedFriends = u'Icke grupperade kontakter'
grpUnknown = u'Ok\xe4nd'
grpUsersAuthorizedByMe = u'Godk\xe4nda av mig'
grpUsersBlockedByMe = u'Blockerade av mig'
grpUsersWaitingMyAuthorization = u'Avvaktar mitt godk\xe4nnande'
leaAddDeclined = u'Till\xe4gg nekades'
leaAddedNotAuthorized = u'Den som l\xe4ggs till m\xe5ste vara godk\xe4nd'
leaAdderNotFriend = u'Den som l\xe4gger till m\xe5ste vara en v\xe4n'
leaUnknown = u'Ok\xe4nd'
leaUnsubscribe = u'Avabonnerad'
leaUserIncapable = u'Anv\xe4ndaren kan inte'
leaUserNotFound = u'Anv\xe4ndaren finns inte'
olsAway = u'Tillf\xe4lligt borta'
olsDoNotDisturb = u'St\xf6r ej'
olsNotAvailable = u'Inte tillg\xe4ngligt'
olsOffline = u'Offline'
olsOnline = u'Online'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Ok\xe4nd'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Kvinna'
usexMale = u'Man'
usexUnknown = u'Ok\xe4nd'
vmrConnectError = u'Anslutningsfel'
vmrFileReadError = u'Fill\xe4sningsfel'
vmrFileWriteError = u'Filskrivningsfel'
vmrMiscError = u'Div fel'
vmrNoError = u'Inget fel'
vmrNoPrivilege = u'Voicemail-beh\xf6righet saknas'
vmrNoVoicemail = u'R\xf6stmeddelande saknas'
vmrPlaybackError = u'Uppspelningsfel'
vmrRecordingError = u'Inspelningsfel'
vmrUnknown = u'Ok\xe4nd'
vmsBlank = u'Tomt'
vmsBuffering = u'Buffrar'
vmsDeleting = u'Tar bort'
vmsDownloading = u'Laddar ner'
vmsFailed = u'Misslyckades'
vmsNotDownloaded = u'Inte nerladdat'
vmsPlayed = u'Uppspelat'
vmsPlaying = u'Spelar upp'
vmsRecorded = u'Inspelat'
vmsRecording = u'Spelar in r\xf6stmeddelande'
vmsUnknown = u'Ok\xe4nd'
vmsUnplayed = u'Inte uppspelat'
vmsUploaded = u'Uppladdat'
vmsUploading = u'Laddar upp'
vmtCustomGreeting = u'S\xe4rskild h\xe4lsning'
vmtDefaultGreeting = u'Standardh\xe4lsning'
vmtIncoming = u'Nytt r\xf6stmeddelande'
vmtOutgoing = u'Utg\xe5ende'
vmtUnknown = u'Ok\xe4nd'
vssAvailable = u'Tillg\xe4ngligt'
vssNotAvailable = u'Inte tillg\xe4ngligt'
vssPaused = u'Pausat'
vssRejected = u'Nekades'
vssRunning = u'P\xe5g\xe5r'
vssStarting = u'Startar'
vssStopping = u'Stannar'
vssUnknown = u'Ok\xe4nd'
