apiAttachAvailable = u'API saatavilla'
apiAttachNotAvailable = u'Ei saatavilla'
apiAttachPendingAuthorization = u'Odottaa valtuutusta'
apiAttachRefused = u'Ev\xe4tty'
apiAttachSuccess = u'Onnistui'
apiAttachUnknown = u'Tuntematon'
budDeletedFriend = u'Poistettu yst\xe4v\xe4listasta'
budFriend = u'Yst\xe4v\xe4'
budNeverBeenFriend = u'Ei aiempia yst\xe4v\xe4listauksia'
budPendingAuthorization = u'Odottaa valtuutusta'
budUnknown = u'Tuntematon'
cfrBlockedByRecipient = u'Vastaanottaja esti soiton'
cfrMiscError = u'Sekal virhe'
cfrNoCommonCodec = u'Ei yleinen koodekki'
cfrNoProxyFound = u'Proxy ei l\xf6ytynyt'
cfrNotAuthorizedByRecipient = u'K\xe4ytt\xe4j\xe4ll\xe4 ei ole vastaanottajan hyv\xe4ksynt\xe4\xe4'
cfrRecipientNotFriend = u'Vastaanottaja ei ole yst\xe4v\xe4'
cfrRemoteDeviceError = u'Ongelma et\xe4-\xe4\xe4nilaitteessa'
cfrSessionTerminated = u'Istunto p\xe4\xe4ttyi'
cfrSoundIOError = u'\xc4\xe4nen I/O-virhe'
cfrSoundRecordingError = u'\xc4\xe4nentallennusvirhe'
cfrUnknown = u'Tuntematon'
cfrUserDoesNotExist = u'Tuntematon k\xe4ytt\xe4j\xe4/puhelinnumero'
cfrUserIsOffline = u'H\xe4n on Offline-tilassa'
chsAllCalls = u'Vanha dialogi'
chsDialog = u'Dialogi'
chsIncomingCalls = u'Multi-chat odottaa hyv\xe4ksynt\xf6j\xe4'
chsLegacyDialog = u'Vanha dialogi'
chsMissedCalls = u'Dialogi'
chsMultiNeedAccept = u'Multi-chat odottaa hyv\xe4ksynt\xf6j\xe4'
chsMultiSubscribed = u'Multi tilattu'
chsOutgoingCalls = u'Multi tilattu'
chsUnknown = u'Tuntematon'
chsUnsubscribed = u'Ei tilaaja'
clsBusy = u'Varattu'
clsCancelled = u'Peruutettu'
clsEarlyMedia = u'K\xe4sittelee ennakkomediaa (Early Media)'
clsFailed = u'Ik\xe4v\xe4 kyll\xe4, puhelu ep\xe4onnistui!'
clsFinished = u'Valmis'
clsInProgress = u'Puhelu k\xe4ynniss\xe4'
clsLocalHold = u'Paikalliseti pidossa'
clsMissed = u'vastaamaton puhelu'
clsOnHold = u'Pidossa'
clsRefused = u'Ev\xe4tty'
clsRemoteHold = u'Et\xe4pidossa'
clsRinging = u'soittamassa'
clsRouting = u'Reitittt\xe4\xe4'
clsTransferred = u'Tuntematon'
clsTransferring = u'Tuntematon'
clsUnknown = u'Tuntematon'
clsUnplaced = u'Ei koskaan valittu'
clsVoicemailBufferingGreeting = u'Puskuroi tervehdyst\xe4'
clsVoicemailCancelled = u'Puheposti on peruutettu'
clsVoicemailFailed = u'Puheposti ep\xe4onnistui'
clsVoicemailPlayingGreeting = u'Toistaa tervehdyst\xe4'
clsVoicemailRecording = u'Puhepostin \xe4\xe4nitys'
clsVoicemailSent = u'Puheposti on l\xe4hetetty'
clsVoicemailUploading = u'Lataa puhepostia'
cltIncomingP2P = u'Saapuva vertaissoitto'
cltIncomingPSTN = u'Saapuva puhelinsoitto'
cltOutgoingP2P = u'L\xe4htev\xe4 vertaissoitto'
cltOutgoingPSTN = u'L\xe4htev\xe4 puhelinsoitto'
cltUnknown = u'Tuntematon'
cmeAddedMembers = u'Lis\xe4tty j\xe4senet'
cmeCreatedChatWith = u'Luotu chat-yhteys'
cmeEmoted = u'Tuntematon'
cmeLeft = u'Poistunut'
cmeSaid = u'Sanottu'
cmeSawMembers = u'N\xe4hty j\xe4senet'
cmeSetTopic = u'Aseta aihe'
cmeUnknown = u'Tuntematon'
cmsRead = u'Lue'
cmsReceived = u'Vastaanotettu'
cmsSending = u'L\xe4hetet\xe4\xe4n...'
cmsSent = u'L\xe4hetetty'
cmsUnknown = u'Tuntematon'
conConnecting = u'Yhdistet\xe4\xe4n'
conOffline = u'Offline-tila'
conOnline = u'Online-tila'
conPausing = u'Tauko'
conUnknown = u'Tuntematon'
cusAway = u'Poistunut'
cusDoNotDisturb = u'\xc4l\xe4 h\xe4iritse'
cusInvisible = u'Huomaamaton'
cusLoggedOut = u'Offline-tila'
cusNotAvailable = u'Ei saatavilla'
cusOffline = u'Offline-tila'
cusOnline = u'Online-tila'
cusSkypeMe = u'Soita minulle'
cusUnknown = u'Tuntematon'
cvsBothEnabled = u'Videon l\xe4hetys ja vastaanotto'
cvsNone = u'Ei videota'
cvsReceiveEnabled = u'Videon vastaanotto'
cvsSendEnabled = u'Videon l\xe4hetys'
cvsUnknown = u''
grpAllFriends = u'Kaikki yst\xe4v\xe4t'
grpAllUsers = u'Kaikki k\xe4ytt\xe4j\xe4t'
grpCustomGroup = u'R\xe4\xe4t\xe4l\xf6ity'
grpOnlineFriends = u'Netiss\xe4 olevat yst\xe4v\xe4t'
grpPendingAuthorizationFriends = u'Odottaa valtuutusta'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'\xc4skett\xe4iset yhteydet'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype-yst\xe4v\xe4t'
grpSkypeOutFriends = u'SkypeOut-yst\xe4v\xe4t'
grpUngroupedFriends = u'Ryhmitt\xe4m\xe4tt\xf6m\xe4t yst\xe4v\xe4ni'
grpUnknown = u'Tuntematon'
grpUsersAuthorizedByMe = u'Valtuutin'
grpUsersBlockedByMe = u'Estin'
grpUsersWaitingMyAuthorization = u'Odottaa valtuutustani'
leaAddDeclined = u'Lis\xe4ys torjuttu'
leaAddedNotAuthorized = u'Lis\xe4tyn t\xe4ytyy olla valtuutettu'
leaAdderNotFriend = u'Lis\xe4\xe4j\xe4n t\xe4ytyy olla yst\xe4v\xe4'
leaUnknown = u'Tuntematon'
leaUnsubscribe = u'Ei tilaaja'
leaUserIncapable = u'K\xe4ytt\xe4j\xe4 esteellinen'
leaUserNotFound = u'K\xe4ytt\xe4j\xe4\xe4 ei l\xf6ytynyt'
olsAway = u'Poistunut'
olsDoNotDisturb = u'\xc4l\xe4 h\xe4iritse'
olsNotAvailable = u'Ei saatavilla'
olsOffline = u'Offline-tila'
olsOnline = u'Online-tila'
olsSkypeMe = u'Soita minulle'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Tuntematon'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Nainen'
usexMale = u'Mies'
usexUnknown = u'Tuntematon'
vmrConnectError = u'Yhdist\xe4misvirhe'
vmrFileReadError = u'Tiedostonlukuvirhe'
vmrFileWriteError = u'Tiedostonkirjoitusvirhe'
vmrMiscError = u'Sekal virhe'
vmrNoError = u'Ei virhett\xe4'
vmrNoPrivilege = u'Ei puhepostioikeutta'
vmrNoVoicemail = u'Tuntematon puheposti'
vmrPlaybackError = u'Toistovirhe'
vmrRecordingError = u'Tallennusvirhe'
vmrUnknown = u'Tuntematon'
vmsBlank = u'Tyhj\xe4'
vmsBuffering = u'Puskuroidaan'
vmsDeleting = u'Poistetaan'
vmsDownloading = u'Imuroidaan'
vmsFailed = u'Ep\xe4onnistui'
vmsNotDownloaded = u'Ei imuroitu'
vmsPlayed = u'Toistettu'
vmsPlaying = u'Toistetaan'
vmsRecorded = u'Tallennettu'
vmsRecording = u'Puhepostin \xe4\xe4nitys'
vmsUnknown = u'Tuntematon'
vmsUnplayed = u'Ei toistettu'
vmsUploaded = u'Ladattu'
vmsUploading = u'Ladataan'
vmtCustomGreeting = u'R\xe4\xe4t\xe4l\xf6ity tervehdys'
vmtDefaultGreeting = u'Oletustervehdys'
vmtIncoming = u'saapuva puheposti'
vmtOutgoing = u'L\xe4htev\xe4'
vmtUnknown = u'Tuntematon'
vssAvailable = u'Saatavilla'
vssNotAvailable = u'Ei saatavilla'
vssPaused = u'Tauko'
vssRejected = u'Torjuttu'
vssRunning = u'Meneill\xe4\xe4n'
vssStarting = u'Aloittaa'
vssStopping = u'Lopetetaan'
vssUnknown = u'Tuntematon'
