apiAttachAvailable = u'API disponible'
apiAttachNotAvailable = u'No disponible'
apiAttachPendingAuthorization = u'Autorizaci\xf3n pendiente'
apiAttachRefused = u'Rechazado'
apiAttachSuccess = u'Conectado'
apiAttachUnknown = u'Desconocido'
budDeletedFriend = u'Borrado de la lista de contactos'
budFriend = u'Contacto'
budNeverBeenFriend = u'Nunca estuvo en la lista de contactos'
budPendingAuthorization = u'Autorizaci\xf3n pendiente'
budUnknown = u'Desconocido'
cfrBlockedByRecipient = u'Llamada bloqueada por el destinatario'
cfrMiscError = u'Error de car\xe1cter general'
cfrNoCommonCodec = u'Ning\xfan c\xf3dec com\xfan'
cfrNoProxyFound = u'No se encontr\xf3 proxy'
cfrNotAuthorizedByRecipient = u'El usuario actual no est\xe1 autorizado por el destinatario'
cfrRecipientNotFriend = u'El destinatario no es un contacto'
cfrRemoteDeviceError = u'Existe un problema con el dispositivo de sonido remoto'
cfrSessionTerminated = u'Sesi\xf3n terminada'
cfrSoundIOError = u'Error de E/S de sonido'
cfrSoundRecordingError = u'Error de grabaci\xf3n de sonido'
cfrUnknown = u'Desconocido'
cfrUserDoesNotExist = u'El usuario o el n\xfamero telef\xf3nico no existen'
cfrUserIsOffline = u'Est\xe1 desconectado/a'
chsAllCalls = u'Di\xe1logos heredados'
chsDialog = u'Di\xe1logo'
chsIncomingCalls = u'Esperando aceptaci\xf3n grupal'
chsLegacyDialog = u'Di\xe1logos heredados'
chsMissedCalls = u'Di\xe1logo'
chsMultiNeedAccept = u'Esperando aceptaci\xf3n grupal'
chsMultiSubscribed = u'Grupal suscrita'
chsOutgoingCalls = u'Grupal suscrita'
chsUnknown = u'Desconocido'
chsUnsubscribed = u'No suscrito'
clsBusy = u'Ocupado'
clsCancelled = u'Cancelado'
clsEarlyMedia = u'Reproduciendo medios iniciales (Early Media)'
clsFailed = u'Perd\xf3n, llamada fallida!'
clsFinished = u'Finalizada'
clsInProgress = u'Llamada en curso'
clsLocalHold = u'En espera local'
clsMissed = u'Llamada perdida'
clsOnHold = u'En espera'
clsRefused = u'Rechazado'
clsRemoteHold = u'En espera remota'
clsRinging = u'helistanud'
clsRouting = u'Enrutando'
clsTransferred = u'Desconocido'
clsTransferring = u'Desconocido'
clsUnknown = u'Desconocido'
clsUnplaced = u'Nunca se realiz\xf3'
clsVoicemailBufferingGreeting = u'Almacenando saludo en el b\xfafer'
clsVoicemailCancelled = u'Mensaje de voz cancelado'
clsVoicemailFailed = u'Fallo del buz\xf3n del voz'
clsVoicemailPlayingGreeting = u'Reproduciendo saludo'
clsVoicemailRecording = u'Grabando mensaje de voz'
clsVoicemailSent = u'Mensaje de voz enviado'
clsVoicemailUploading = u'Cargando mensaje de voz'
cltIncomingP2P = u'Llamada recibida de par a par'
cltIncomingPSTN = u'Llamada recibida'
cltOutgoingP2P = u'Llamada realizada de par a par'
cltOutgoingPSTN = u'Llamada realizada'
cltUnknown = u'Desconocido'
cmeAddedMembers = u'Miembros agregados'
cmeCreatedChatWith = u'Conversaci\xf3n iniciada con'
cmeEmoted = u'Desconocido'
cmeLeft = u'Conversaci\xf3n abandonada'
cmeSaid = u'Dijo'
cmeSawMembers = u'Miembros vistos'
cmeSetTopic = u'Definici\xf3n del tema'
cmeUnknown = u'Desconocido'
cmsRead = u'Le\xeddo'
cmsReceived = u'Recibido'
cmsSending = u'Enviando...'
cmsSent = u'Enviado'
cmsUnknown = u'Desconocido'
conConnecting = u'Conectando'
conOffline = u'Desconectado'
conOnline = u'Conectado'
conPausing = u'En pausa'
conUnknown = u'Desconocido'
cusAway = u'Ausente'
cusDoNotDisturb = u'Ocupado'
cusInvisible = u'Invisible'
cusLoggedOut = u'Desconectado'
cusNotAvailable = u'No disponible'
cusOffline = u'Desconectado'
cusOnline = u'Conectado'
cusSkypeMe = u'Skyp\xe9ame'
cusUnknown = u'Desconocido'
cvsBothEnabled = u'Enviando y recibiendo video'
cvsNone = u'Sin video'
cvsReceiveEnabled = u'Recibiendo video'
cvsSendEnabled = u'Enviando video'
cvsUnknown = u''
grpAllFriends = u'Todos los contactos'
grpAllUsers = u'Todos los usuarios'
grpCustomGroup = u'Personalizado'
grpOnlineFriends = u'Contactos conectados'
grpPendingAuthorizationFriends = u'Autorizaci\xf3n pendiente'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Usuarios contactados recientemente'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Contactos de Skype'
grpSkypeOutFriends = u'Contactos de SkypeOut'
grpUngroupedFriends = u'Contactos no agrupados'
grpUnknown = u'Desconocido'
grpUsersAuthorizedByMe = u'Autorizado por m\xed'
grpUsersBlockedByMe = u'Bloqueado por m\xed'
grpUsersWaitingMyAuthorization = u'Esperando mi autorizaci\xf3n'
leaAddDeclined = u'Agregado rechazado'
leaAddedNotAuthorized = u'La persona agregada deber estar autorizada'
leaAdderNotFriend = u'Quien agrega debe ser un contacto'
leaUnknown = u'Desconocido'
leaUnsubscribe = u'No suscrito'
leaUserIncapable = u'Usuario inhabilitado'
leaUserNotFound = u'No se encontr\xf3 el usuario'
olsAway = u'Ausente'
olsDoNotDisturb = u'Ocupado'
olsNotAvailable = u'No disponible'
olsOffline = u'Desconectado'
olsOnline = u'Conectado'
olsSkypeMe = u'Skyp\xe9ame'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Desconocido'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Mujer'
usexMale = u'Hombre'
usexUnknown = u'Desconocido'
vmrConnectError = u'Error de conexi\xf3n'
vmrFileReadError = u'Error de lectura en archivo'
vmrFileWriteError = u'Error de escritura en archivo'
vmrMiscError = u'Error de car\xe1cter general'
vmrNoError = u'No se produjo error'
vmrNoPrivilege = u'Sin privilegio de mensaje de voz'
vmrNoVoicemail = u'Sin mensaje de voz'
vmrPlaybackError = u'Error de reproducci\xf3n'
vmrRecordingError = u'Error de grabaci\xf3n'
vmrUnknown = u'Desconocido'
vmsBlank = u'En blanco'
vmsBuffering = u'Almacenando'
vmsDeleting = u'Borrando'
vmsDownloading = u'Descargando'
vmsFailed = u'No enviado'
vmsNotDownloaded = u'No se descarg\xf3'
vmsPlayed = u'Reproducido'
vmsPlaying = u'Reproduciendo'
vmsRecorded = u'Grabado'
vmsRecording = u'Grabando mensaje de voz'
vmsUnknown = u'Desconocido'
vmsUnplayed = u'No se reprodujo'
vmsUploaded = u'Cargado'
vmsUploading = u'Cargando'
vmtCustomGreeting = u'Saludo personalizado'
vmtDefaultGreeting = u'Saludo predeterminado'
vmtIncoming = u'correo de voz entrante'
vmtOutgoing = u'Saliente'
vmtUnknown = u'Desconocido'
vssAvailable = u'Disponible'
vssNotAvailable = u'No disponible'
vssPaused = u'Interrumpida'
vssRejected = u'Rechazada'
vssRunning = u'En curso'
vssStarting = u'Iniciando'
vssStopping = u'Detenida'
vssUnknown = u'Desconocido'
