apiAttachAvailable = u'API forefindes'
apiAttachNotAvailable = u'Optaget'
apiAttachPendingAuthorization = u'Afventer godkendelse'
apiAttachRefused = u'Afvist'
apiAttachSuccess = u'Succes'
apiAttachUnknown = u'Ukendt'
budDeletedFriend = u'Slettet fra liste over kontaktpersoner'
budFriend = u'Ven'
budNeverBeenFriend = u'Aldrig v\xe6ret p\xe5 liste over kontaktpersoner'
budPendingAuthorization = u'Afventer godkendelse'
budUnknown = u'Ukendt'
cfrBlockedByRecipient = u'Opkald blokeret af modtager'
cfrMiscError = u'Anden fejl'
cfrNoCommonCodec = u'Intet f\xe6lles codec fundet'
cfrNoProxyFound = u'Ingen proxy fundet'
cfrNotAuthorizedByRecipient = u'Aktuel bruger er ikke godkendt af modtager'
cfrRecipientNotFriend = u'Modtager er ikke en ven'
cfrRemoteDeviceError = u'Problem med lydenhed hos modparten'
cfrSessionTerminated = u'Session afsluttet'
cfrSoundIOError = u'Lyd-I/O fejl'
cfrSoundRecordingError = u'Lydoptagelsesfejl'
cfrUnknown = u'Ukendt'
cfrUserDoesNotExist = u'Bruger/telefonnummer findes ikke'
cfrUserIsOffline = u'Han eller hun er offline'
chsAllCalls = u'Dialog med tidligere version'
chsDialog = u'Dialog'
chsIncomingCalls = u'Behov for \xa0accept af flere brugere'
chsLegacyDialog = u'Dialog med tidligere version'
chsMissedCalls = u'Dialog'
chsMultiNeedAccept = u'Behov for \xa0accept af flere brugere'
chsMultiSubscribed = u'Flere brugere deltager'
chsOutgoingCalls = u'Flere brugere deltager'
chsUnknown = u'Ukendt'
chsUnsubscribed = u'Afmeldt'
clsBusy = u'Optaget'
clsCancelled = u'Afbrudt'
clsEarlyMedia = u'Afspiller startmedier (Early Media)'
clsFailed = u'Opkaldet mislykkedes!'
clsFinished = u'Afsluttet'
clsInProgress = u'udf\xf8rer'
clsLocalHold = u'Opkald parkeret (lokalt)'
clsMissed = u'Mistet opkald'
clsOnHold = u'Parkeret'
clsRefused = u'Afvist'
clsRemoteHold = u'Opkald parkeret (fjernsystem)'
clsRinging = u'ringer'
clsRouting = u'Omdirigerer'
clsTransferred = u'Ukendt'
clsTransferring = u'Ukendt'
clsUnknown = u'Ukendt'
clsUnplaced = u'Aldrig foretaget'
clsVoicemailBufferingGreeting = u'Bufferlagring af besked'
clsVoicemailCancelled = u'Stemmebesked er afbrudt'
clsVoicemailFailed = u'Stemmebesked fejlet'
clsVoicemailPlayingGreeting = u'Afspiller besked'
clsVoicemailRecording = u'Optager stemmebesked'
clsVoicemailSent = u'Stemmebesked er afsendt'
clsVoicemailUploading = u'Overf\xf8rer stemmebesked'
cltIncomingP2P = u'Indg\xe5ende peer-to-peer-opkald'
cltIncomingPSTN = u'Indg\xe5ende telefonopkald'
cltOutgoingP2P = u'Udg\xe5ende peer-to-peer-opkald'
cltOutgoingPSTN = u'Udg\xe5ende telefonopkald'
cltUnknown = u'Ukendt'
cmeAddedMembers = u'Tilf\xf8jede medlemmer'
cmeCreatedChatWith = u'Oprettet chat med'
cmeEmoted = u'Ukendt'
cmeLeft = u'Forladt'
cmeSaid = u'Sagt'
cmeSawMembers = u'S\xe5 medlemmer'
cmeSetTopic = u'Angiv emne'
cmeUnknown = u'Ukendt'
cmsRead = u'L\xe6st'
cmsReceived = u'Modtaget'
cmsSending = u'Sender...'
cmsSent = u'Sendt'
cmsUnknown = u'Ukendt'
conConnecting = u'Tilslutter'
conOffline = u'Offline'
conOnline = u'Online'
conPausing = u'Midlertidigt afbrudt'
conUnknown = u'Ukendt'
cusAway = u'Ikke til stede'
cusDoNotDisturb = u'Vil ikke forstyrres'
cusInvisible = u'Usynlig'
cusLoggedOut = u'Offline'
cusNotAvailable = u'Optaget'
cusOffline = u'Offline'
cusOnline = u'Online'
cusSkypeMe = u'Ring til mig'
cusUnknown = u'Ukendt'
cvsBothEnabled = u'Video send og modtag'
cvsNone = u'Ingen video'
cvsReceiveEnabled = u'Video modtag'
cvsSendEnabled = u'Video send'
cvsUnknown = u''
grpAllFriends = u'Alle venner'
grpAllUsers = u'Alle brugere'
grpCustomGroup = u'Tilpasset'
grpOnlineFriends = u'Online-venner'
grpPendingAuthorizationFriends = u'Afventer godkendelse'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Venner kontaktet for nylig'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype-venner'
grpSkypeOutFriends = u'SkypeOut-venner'
grpUngroupedFriends = u'Ikke-grupperede venner'
grpUnknown = u'Ukendt'
grpUsersAuthorizedByMe = u'Godkendt af mig'
grpUsersBlockedByMe = u'Blokeret af mig'
grpUsersWaitingMyAuthorization = u'Afventer min godkendelse'
leaAddDeclined = u'Tilf\xf8jelse afvist'
leaAddedNotAuthorized = u'Tilf\xf8jet skal v\xe6re godkendt'
leaAdderNotFriend = u'Tilf\xf8jet skal v\xe6re ven'
leaUnknown = u'Ukendt'
leaUnsubscribe = u'Afmeldt'
leaUserIncapable = u'Bruger kan ikke forts\xe6tte'
leaUserNotFound = u'Bruger ikke fundet'
olsAway = u'Ikke til stede'
olsDoNotDisturb = u'Vil ikke forstyrres'
olsNotAvailable = u'Optaget'
olsOffline = u'Offline'
olsOnline = u'Online'
olsSkypeMe = u'Ring til mig'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Ukendt'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Kvinde'
usexMale = u'Mand'
usexUnknown = u'Ukendt'
vmrConnectError = u'Fejl ved forbindelse'
vmrFileReadError = u'Der opstod en fejl under l\xe6sning af filen'
vmrFileWriteError = u'Der opstod en fejl under lagring af filen'
vmrMiscError = u'Anden fejl'
vmrNoError = u'Ingen fejl'
vmrNoPrivilege = u'Du kan ikke l\xe6gge en stemmebesked'
vmrNoVoicemail = u'Stemmebeskeden findes ikke'
vmrPlaybackError = u'Afspilningsfejl'
vmrRecordingError = u'Indspilningsfejl'
vmrUnknown = u'Ukendt'
vmsBlank = u'Blank'
vmsBuffering = u'Bufferlagrer'
vmsDeleting = u'Sletter'
vmsDownloading = u'Henter'
vmsFailed = u'Mislykkedes'
vmsNotDownloaded = u'Ikke hentet'
vmsPlayed = u'Afspillet'
vmsPlaying = u'Afspiller'
vmsRecorded = u'Optaget'
vmsRecording = u'Optager stemmebesked'
vmsUnknown = u'Ukendt'
vmsUnplayed = u'Ikke afspillet'
vmsUploaded = u'Overf\xf8rt'
vmsUploading = u'Overf\xf8rer'
vmtCustomGreeting = u'Tilpasset besked'
vmtDefaultGreeting = u'Standardbesked'
vmtIncoming = u'indg\xe5ende voicemail'
vmtOutgoing = u'Udg\xe5ende'
vmtUnknown = u'Ukendt'
vssAvailable = u'Ledig'
vssNotAvailable = u'Optaget'
vssPaused = u'Midlertidigt afbrudt'
vssRejected = u'Afvist'
vssRunning = u'K\xf8rer'
vssStarting = u'Starter'
vssStopping = u'Stopper'
vssUnknown = u'Ukendt'
