apiAttachAvailable = u'API\u304c\u898b\u3064\u304b\u308a\u307e\u3057\u305f'
apiAttachNotAvailable = u'\u7121\u52b9'
apiAttachPendingAuthorization = u'\u8a8d\u8a3c\u5f85\u3061'
apiAttachRefused = u'\u62d2\u5426\u3055\u308c\u307e\u3057\u305f'
apiAttachSuccess = u'\u6210\u529f'
apiAttachUnknown = u'\u4e0d\u660e'
budDeletedFriend = u'\u53cb\u4eba\u30ea\u30b9\u30c8\u304b\u3089\u524a\u9664\u3055\u308c\u307e\u3057\u305f'
budFriend = u'\u53cb\u4eba'
budNeverBeenFriend = u'\u53cb\u4eba\u30ea\u30b9\u30c8\u306b\u672a\u8ffd\u52a0'
budPendingAuthorization = u'\u8a8d\u8a3c\u5f85\u3061'
budUnknown = u'\u4e0d\u660e'
cfrBlockedByRecipient = u'\u76f8\u624b\u306b\u901a\u8a71\u304c\u30d6\u30ed\u30c3\u30af\u3055\u308c\u307e\u3057\u305f'
cfrMiscError = u'\u305d\u306e\u4ed6\u30a8\u30e9\u30fc'
cfrNoCommonCodec = u'\u4e00\u822c\u7684\u306a\u30b3\u30fc\u30c7\u30c3\u30af\u3067\u306f\u3042\u308a\u307e\u305b\u3093'
cfrNoProxyFound = u'\u30d7\u30ed\u30ad\u30b7\u304c\u898b\u3064\u304b\u308a\u307e\u305b\u3093'
cfrNotAuthorizedByRecipient = u'\u30e6\u30fc\u30b6\u304c\u53d7\u4fe1\u8005\u306b\u8a8d\u8a3c\u3055\u308c\u3066\u3044\u308b\u5fc5\u8981\u304c\u3042\u308a\u307e\u3059\u3002'
cfrRecipientNotFriend = u'\u53d7\u4fe1\u8005\u306f\u53cb\u4eba\u3068\u3057\u3066\u767b\u9332\u3055\u308c\u3066\u3044\u307e\u305b\u3093'
cfrRemoteDeviceError = u'\u30ea\u30e2\u30fc\u30c8\u30aa\u30fc\u30c7\u30a3\u30aa\u30c7\u30d0\u30a4\u30b9\u306b\u554f\u984c\u304c\u3042\u308a\u307e\u3059'
cfrSessionTerminated = u'\u30bb\u30c3\u30b7\u30e7\u30f3\u7d42\u4e86'
cfrSoundIOError = u'\u97f3\u58f0\u51fa\u5165\u529b\u30a8\u30e9\u30fc'
cfrSoundRecordingError = u'\u97f3\u58f0\u9332\u97f3\u30a8\u30e9\u30fc'
cfrUnknown = u'\u4e0d\u660e'
cfrUserDoesNotExist = u'\u30e6\u30fc\u30b6\u30fb\u96fb\u8a71\u756a\u53f7\u304c\u5b58\u5728\u3057\u307e\u305b\u3093'
cfrUserIsOffline = u'\u30aa\u30d5\u30e9\u30a4\u30f3\u3067\u3059'
chsAllCalls = u'\u30ec\u30ac\u30b7\u30fc\u30c0\u30a4\u30a2\u30ed\u30b0'
chsDialog = u'\u30c0\u30a4\u30a2\u30ed\u30b0'
chsIncomingCalls = u'\u8907\u6570\u53d7\u4fe1\u8a31\u53ef\u5f85\u3061\u3042\u308a'
chsLegacyDialog = u'\u30ec\u30ac\u30b7\u30fc\u30c0\u30a4\u30a2\u30ed\u30b0'
chsMissedCalls = u'\u30c0\u30a4\u30a2\u30ed\u30b0'
chsMultiNeedAccept = u'\u8907\u6570\u53d7\u4fe1\u8a31\u53ef\u5f85\u3061\u3042\u308a'
chsMultiSubscribed = u'\u8907\u6570\u5951\u7d04\u3042\u308a'
chsOutgoingCalls = u'\u8907\u6570\u5951\u7d04\u3042\u308a'
chsUnknown = u'\u4e0d\u660e'
chsUnsubscribed = u'\u5951\u7d04\u306a\u3057'
clsBusy = u'\u53d6\u308a\u8fbc\u307f\u4e2d'
clsCancelled = u'\u30ad\u30e3\u30f3\u30bb\u30eb\u3055\u308c\u307e\u3057\u305f'
clsEarlyMedia = u'\u65e9\u671f\u30e1\u30c7\u30a3\u30a2\u518d\u751f\u4e2d'
clsFailed = u'\u901a\u8a71\u63a5\u7d9a\u306b\u5931\u6557\u3057\u307e\u3057\u305f\u3002'
clsFinished = u'\u7d42\u4e86'
clsInProgress = u'\u901a\u8a71\u4e2d'
clsLocalHold = u'\u81ea\u8eab\u306b\u3088\u308b\u4e00\u6642\u505c\u6b62\u4e2d'
clsMissed = u'\u4ef6\u306e\u4e0d\u5728\u7740\u4fe1'
clsOnHold = u'\u4fdd\u7559\u4e2d'
clsRefused = u'\u62d2\u5426\u3055\u308c\u307e\u3057\u305f'
clsRemoteHold = u'\u76f8\u624b\u304c'
clsRinging = u'\u901a\u8a71\u4e2d'
clsRouting = u'\u30eb\u30fc\u30c6\u30a3\u30f3\u30b0\u4e2d'
clsTransferred = u'\u4e0d\u660e'
clsTransferring = u'\u4e0d\u660e'
clsUnknown = u'\u4e0d\u660e'
clsUnplaced = u'\u901a\u8a71\u306f\u767a\u4fe1\u3055\u308c\u307e\u305b\u3093\u3067\u3057\u305f'
clsVoicemailBufferingGreeting = u'\u5fdc\u7b54\u30e1\u30c3\u30bb\u30fc\u30b8\u306e\u30d0\u30c3\u30d5\u30a1\u4e2d'
clsVoicemailCancelled = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u304c\u30ad\u30e3\u30f3\u30bb\u30eb\u3055\u308c\u307e\u3057\u305f'
clsVoicemailFailed = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u9001\u4fe1\u5931\u6557'
clsVoicemailPlayingGreeting = u'\u5fdc\u7b54\u30e1\u30c3\u30bb\u30fc\u30b8\u306e\u518d\u751f\u4e2d'
clsVoicemailRecording = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u3092\u9332\u97f3\u4e2d'
clsVoicemailSent = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u304c\u9001\u4fe1\u3055\u308c\u307e\u3057\u305f'
clsVoicemailUploading = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u306e\u30a2\u30c3\u30d7\u30ed\u30fc\u30c9\u4e2d'
cltIncomingP2P = u'P2P\u901a\u8a71\u7740\u4fe1'
cltIncomingPSTN = u'\u96fb\u8a71\u7740\u4fe1'
cltOutgoingP2P = u'P2P\u901a\u8a71\u9001\u4fe1'
cltOutgoingPSTN = u'\u96fb\u8a71\u9001\u4fe1'
cltUnknown = u'\u4e0d\u660e'
cmeAddedMembers = u'\u30e1\u30f3\u30d0\u30fc\u3092\u8ffd\u52a0\u3057\u307e\u3057\u305f'
cmeCreatedChatWith = u'\u30c1\u30e3\u30c3\u30c8\u3092\u4f5c\u6210\uff1a'
cmeEmoted = u'\u4e0d\u660e'
cmeLeft = u'\u6b8b\u3057\u307e\u3057\u305f'
cmeSaid = u'\u8a00\u3044\u307e\u3057\u305f'
cmeSawMembers = u'\u30e1\u30f3\u30d0\u30fc\u3092\u8868\u793a\u3057\u307e\u3057\u305f'
cmeSetTopic = u'\u30bf\u30a4\u30c8\u30eb\u3092\u8868\u793a'
cmeUnknown = u'\u4e0d\u660e'
cmsRead = u'\u65e2\u8aad'
cmsReceived = u'\u53d7\u4fe1\u5b8c\u4e86'
cmsSending = u'\u9001\u4fe1\u4e2d...'
cmsSent = u'\u9001\u4fe1\u6e08'
cmsUnknown = u'\u4e0d\u660e'
conConnecting = u'\u63a5\u7d9a\u4e2d'
conOffline = u'\u30aa\u30d5\u30e9\u30a4\u30f3'
conOnline = u'\u30aa\u30f3\u30e9\u30a4\u30f3'
conPausing = u'\u4e00\u6642\u505c\u6b62\u4e2d'
conUnknown = u'\u4e0d\u660e'
cusAway = u'\u4e00\u6642\u9000\u5e2d\u4e2d'
cusDoNotDisturb = u'\u53d6\u308a\u8fbc\u307f\u4e2d'
cusInvisible = u'\u30ed\u30b0\u30a4\u30f3\u72b6\u614b\u3092\u96a0\u3059'
cusLoggedOut = u'\u30aa\u30d5\u30e9\u30a4\u30f3'
cusNotAvailable = u'\u7121\u52b9'
cusOffline = u'\u30aa\u30d5\u30e9\u30a4\u30f3'
cusOnline = u'\u30aa\u30f3\u30e9\u30a4\u30f3'
cusSkypeMe = u'Skype Me'
cusUnknown = u'\u4e0d\u660e'
cvsBothEnabled = u'\u30d3\u30c7\u30aa\u9001\u53d7\u4fe1'
cvsNone = u'\u30d3\u30c7\u30aa\u306a\u3057'
cvsReceiveEnabled = u'\u30d3\u30c7\u30aa\u53d7\u4fe1'
cvsSendEnabled = u'\u30d3\u30c7\u30aa\u9001\u4fe1'
cvsUnknown = u''
grpAllFriends = u'\u3059\u3079\u3066\u306e\u53cb\u4eba'
grpAllUsers = u'\u3059\u3079\u3066\u306e\u30e6\u30fc\u30b6'
grpCustomGroup = u'\u30aa\u30ea\u30b8\u30ca\u30eb'
grpOnlineFriends = u'\u30aa\u30f3\u30e9\u30a4\u30f3\u30d5\u30ec\u30f3\u30ba'
grpPendingAuthorizationFriends = u'\u8a8d\u8a3c\u5f85\u3061'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'\u6700\u8fd1\u30b3\u30f3\u30bf\u30af\u30c8\u3057\u305f\u30e6\u30fc\u30b6'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype\u30d5\u30ec\u30f3\u30ba'
grpSkypeOutFriends = u'SkypeOut\u30d5\u30ec\u30f3\u30ba'
grpUngroupedFriends = u'\u30b0\u30eb\u30fc\u30d7\u306b\u5165\u3063\u3066\u3044\u306a\u3044\u30b3\u30f3\u30bf\u30af\u30c8'
grpUnknown = u'\u4e0d\u660e'
grpUsersAuthorizedByMe = u'\u8a8d\u8a3c\u3057\u305f\u30b0\u30eb\u30fc\u30d7'
grpUsersBlockedByMe = u'\u30d6\u30ed\u30c3\u30af\u3057\u305f\u30b0\u30eb\u30fc\u30d7'
grpUsersWaitingMyAuthorization = u'\u8a8d\u8a3c\u5f85\u3061'
leaAddDeclined = u'\u8ffd\u52a0\u62d2\u5426'
leaAddedNotAuthorized = u'\u8ffd\u52a0\u8005\u306f\u8a8d\u8a3c\u3055\u308c\u3066\u3044\u308b\u5fc5\u8981\u304c\u3042\u308a\u307e\u3059'
leaAdderNotFriend = u'\u8ffd\u52a0\u8005\u306f\u53cb\u4eba\u306e\u5fc5\u8981\u304c\u3042\u308a\u307e\u3059'
leaUnknown = u'\u4e0d\u660e'
leaUnsubscribe = u'\u5951\u7d04\u306a\u3057'
leaUserIncapable = u'\u30e6\u30fc\u30b6'
leaUserNotFound = u'\u30e6\u30fc\u30b6\u304c\u898b\u3064\u304b\u308a\u307e\u305b\u3093'
olsAway = u'\u4e00\u6642\u9000\u5e2d\u4e2d'
olsDoNotDisturb = u'\u53d6\u308a\u8fbc\u307f\u4e2d'
olsNotAvailable = u'\u7121\u52b9'
olsOffline = u'\u30aa\u30d5\u30e9\u30a4\u30f3'
olsOnline = u'\u30aa\u30f3\u30e9\u30a4\u30f3'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'\u4e0d\u660e'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'\u5973\u6027'
usexMale = u'\u7537\u6027'
usexUnknown = u'\u4e0d\u660e'
vmrConnectError = u'\u63a5\u7d9a\u30a8\u30e9\u30fc'
vmrFileReadError = u'\u30d5\u30a1\u30a4\u30eb\u8aad\u307f\u8fbc\u307f\u30a8\u30e9\u30fc'
vmrFileWriteError = u'\u30d5\u30a1\u30a4\u30eb\u66f8\u304d\u8fbc\u307f\u30a8\u30e9\u30fc'
vmrMiscError = u'\u305d\u306e\u4ed6\u30a8\u30e9\u30fc'
vmrNoError = u'\u30a8\u30e9\u30fc\u306a\u3057'
vmrNoPrivilege = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u5951\u7d04\u306a\u3057'
vmrNoVoicemail = u'\u8a72\u5f53\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u304c\u898b\u3064\u304b\u308a\u307e\u305b\u3093'
vmrPlaybackError = u'\u518d\u751f\u30a8\u30e9\u30fc'
vmrRecordingError = u'\u9332\u97f3\u30a8\u30e9\u30fc'
vmrUnknown = u'\u4e0d\u660e'
vmsBlank = u'\u7a7a\u6b04'
vmsBuffering = u'\u30d0\u30c3\u30d5\u30a1\u4e2d'
vmsDeleting = u'\u524a\u9664\u4e2d'
vmsDownloading = u'\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9\u4e2d'
vmsFailed = u'\u5931\u6557'
vmsNotDownloaded = u'\u672a\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9'
vmsPlayed = u'\u518d\u751f\u6e08'
vmsPlaying = u'\u518d\u751f\u4e2d'
vmsRecorded = u'\u9332\u97f3\u5b8c\u4e86'
vmsRecording = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u3092\u9332\u97f3\u4e2d'
vmsUnknown = u'\u4e0d\u660e'
vmsUnplayed = u'\u672a\u518d\u751f'
vmsUploaded = u'\u30a2\u30c3\u30d7\u30ed\u30fc\u30c9\u5b8c\u4e86'
vmsUploading = u'\u30a2\u30c3\u30d7\u30ed\u30fc\u30c9\u4e2d'
vmtCustomGreeting = u'\u30aa\u30ea\u30b8\u30ca\u30eb\u5fdc\u7b54\u30e1\u30c3\u30bb\u30fc\u30b8'
vmtDefaultGreeting = u'\u6a19\u6e96\u5fdc\u7b54\u30e1\u30c3\u30bb\u30fc\u30b8'
vmtIncoming = u'voicemail\u3092\u7740\u4fe1\u3057\u305f\u6642'
vmtOutgoing = u'\u9001\u4fe1'
vmtUnknown = u'\u4e0d\u660e'
vssAvailable = u'\u5229\u7528\u53ef\u80fd'
vssNotAvailable = u'\u7121\u52b9'
vssPaused = u'\u4e00\u6642\u505c\u6b62\u4e2d'
vssRejected = u'\u62d2\u5426\u3055\u308c\u307e\u3057\u305f'
vssRunning = u'\u518d\u751f\u4e2d'
vssStarting = u'\u8d77\u52d5\u4e2d'
vssStopping = u'\u505c\u6b62\u4e2d'
vssUnknown = u'\u4e0d\u660e'
