apiAttachAvailable = u'API disponible'
apiAttachNotAvailable = u'Indisponible'
apiAttachPendingAuthorization = u'Autorisation en attente'
apiAttachRefused = u'Refus\xe9'
apiAttachSuccess = u'Connexion r\xe9ussie'
apiAttachUnknown = u'Inconnu'
budDeletedFriend = u'Supprim\xe9 de la liste d\u2019amis'
budFriend = u'Ami'
budNeverBeenFriend = u"N'a jamais \xe9t\xe9 ajout\xe9 \xe0 la liste d\u2019amis"
budPendingAuthorization = u'Autorisation en attente'
budUnknown = u'Inconnu'
cfrBlockedByRecipient = u'Appel bloqu\xe9 par le destinataire'
cfrMiscError = u'Erreurs diverses'
cfrNoCommonCodec = u'Aucun codec en commun'
cfrNoProxyFound = u'Aucun proxy trouv\xe9'
cfrNotAuthorizedByRecipient = u'Utilisateur actuel non autoris\xe9 par le destinataire'
cfrRecipientNotFriend = u'Destinataire n\u2019est pas un ami'
cfrRemoteDeviceError = u'Erreur E/S audio distante'
cfrSessionTerminated = u'Session termin\xe9e'
cfrSoundIOError = u'Erreur E/S son'
cfrSoundRecordingError = u'Erreur d\u2019enregistrement du son'
cfrUnknown = u'Inconnu'
cfrUserDoesNotExist = u'Utilisateur/n\xb0 de t\xe9l\xe9phone inexistant'
cfrUserIsOffline = u'Il/Elle est D\xe9connect\xe9(e)'
chsAllCalls = u'Ancien dialogue'
chsDialog = u'Dialogue'
chsIncomingCalls = u'Attente multi acceptation'
chsLegacyDialog = u'Ancien dialogue'
chsMissedCalls = u'Dialogue'
chsMultiNeedAccept = u'Attente multi acceptation'
chsMultiSubscribed = u'Multi abonn\xe9s'
chsOutgoingCalls = u'Multi abonn\xe9s'
chsUnknown = u'Inconnu'
chsUnsubscribed = u'D\xe9sabonn\xe9'
clsBusy = u'Occup\xe9'
clsCancelled = u'Annul\xe9'
clsEarlyMedia = u'Lecture flux m\xe9dia (Early Media)'
clsFailed = u"D\xe9sol\xe9, l'appel a \xe9chou\xe9 !"
clsFinished = u'Termin\xe9'
clsInProgress = u'Appel en cours...'
clsLocalHold = u'En attente locale'
clsMissed = u'Appel en absence'
clsOnHold = u'En attente'
clsRefused = u'Refus\xe9'
clsRemoteHold = u'En attente \xe0 distance'
clsRinging = u'un appel'
clsRouting = u'Routage'
clsTransferred = u'Inconnu'
clsTransferring = u'Inconnu'
clsUnknown = u'Inconnu'
clsUnplaced = u'Jamais plac\xe9'
clsVoicemailBufferingGreeting = u'Buff\xe9risation du message d\u2019accueil'
clsVoicemailCancelled = u'Message vocal annul\xe9'
clsVoicemailFailed = u'Echec du message vocal'
clsVoicemailPlayingGreeting = u'Lecture du message d\u2019accueil'
clsVoicemailRecording = u'Enregistrement sur la boite vocale'
clsVoicemailSent = u'Message vocal envoy\xe9'
clsVoicemailUploading = u'T\xe9l\xe9chargement du message vocal'
cltIncomingP2P = u'Appel P2P entrant'
cltIncomingPSTN = u'Appel entrant'
cltOutgoingP2P = u'Appel P2P sortant'
cltOutgoingPSTN = u'Appel sortant'
cltUnknown = u'Inconnu'
cmeAddedMembers = u'A ajout\xe9 des membres'
cmeCreatedChatWith = u'Cr\xe9\xe9 un dialogue avec'
cmeEmoted = u'Inconnu'
cmeLeft = u'Laiss\xe9'
cmeSaid = u'A dit'
cmeSawMembers = u'A vu des membres'
cmeSetTopic = u'A d\xe9fini un sujet'
cmeUnknown = u'Inconnu'
cmsRead = u'Lu'
cmsReceived = u'Re\xe7u'
cmsSending = u'Envoi en cours...'
cmsSent = u'Envoy\xe9'
cmsUnknown = u'Inconnu'
conConnecting = u'Connexion en cours'
conOffline = u'D\xe9connect\xe9'
conOnline = u'Connect\xe9'
conPausing = u'En pause'
conUnknown = u'Inconnu'
cusAway = u'Absent'
cusDoNotDisturb = u'Ne pas d\xe9ranger'
cusInvisible = u'Invisible'
cusLoggedOut = u'D\xe9connect\xe9'
cusNotAvailable = u'Indisponible'
cusOffline = u'D\xe9connect\xe9'
cusOnline = u'Connect\xe9'
cusSkypeMe = u'Accessible'
cusUnknown = u'Inconnu'
cvsBothEnabled = u'Envoi et r\xe9ception vid\xe9o'
cvsNone = u'Pas de vid\xe9o'
cvsReceiveEnabled = u'R\xe9ception vid\xe9o'
cvsSendEnabled = u'Envoi vid\xe9o'
cvsUnknown = u''
grpAllFriends = u'Tous les amis'
grpAllUsers = u'Tous les utilisateurs'
grpCustomGroup = u'Personnalis\xe9'
grpOnlineFriends = u'Amis en ligne'
grpPendingAuthorizationFriends = u'Autorisation en attente'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Utilisateurs r\xe9cemment contact\xe9s'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Amis Skype'
grpSkypeOutFriends = u'Amis SkypeOut'
grpUngroupedFriends = u'Amis sans groupe'
grpUnknown = u'Inconnu'
grpUsersAuthorizedByMe = u'Autoris\xe9 par moi'
grpUsersBlockedByMe = u'Bloqu\xe9 par moi'
grpUsersWaitingMyAuthorization = u'En attente de mon autorisation'
leaAddDeclined = u'Ajout refus\xe9'
leaAddedNotAuthorized = u'La personne ajout\xe9e doit \xeatre autoris\xe9e'
leaAdderNotFriend = u'La personne qui ajoute doit \xeatre un ami'
leaUnknown = u'Inconnu'
leaUnsubscribe = u'D\xe9sabonn\xe9'
leaUserIncapable = u'Utilisateur incapable'
leaUserNotFound = u'Utilisateur introuvable'
olsAway = u'Absent'
olsDoNotDisturb = u'Ne pas d\xe9ranger'
olsNotAvailable = u'Indisponible'
olsOffline = u'D\xe9connect\xe9'
olsOnline = u'Connect\xe9'
olsSkypeMe = u'Accessible'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Inconnu'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Femme'
usexMale = u'Homme'
usexUnknown = u'Inconnu'
vmrConnectError = u'Erreur de connexion'
vmrFileReadError = u'Erreur de lecture fichier'
vmrFileWriteError = u'Erreur d\u2019\xe9criture fichier'
vmrMiscError = u'Erreurs diverses'
vmrNoError = u'Pas d\u2019erreur'
vmrNoPrivilege = u'Pas de privil\xe8ge Voicemail'
vmrNoVoicemail = u'Aucun message vocal de ce type'
vmrPlaybackError = u'Erreur de lecture'
vmrRecordingError = u'Erreur d\u2019enregistrement'
vmrUnknown = u'Inconnu'
vmsBlank = u'Vierge'
vmsBuffering = u'Buff\xe9risation en cours'
vmsDeleting = u'Suppression en cours'
vmsDownloading = u'T\xe9l\xe9chargement en cours'
vmsFailed = u'\xc9chec'
vmsNotDownloaded = u'Non t\xe9l\xe9charg\xe9'
vmsPlayed = u'Lu'
vmsPlaying = u'Lecture en cours'
vmsRecorded = u'Enregistr\xe9'
vmsRecording = u'Enregistrement sur la boite vocale'
vmsUnknown = u'Inconnu'
vmsUnplayed = u'Non lu'
vmsUploaded = u'T\xe9l\xe9charg\xe9'
vmsUploading = u'T\xe9l\xe9chargement en cours'
vmtCustomGreeting = u'Message d\u2019accueil personnalis\xe9'
vmtDefaultGreeting = u'Message d\u2019accueil par d\xe9faut'
vmtIncoming = u'R\xe9ception de message sur la boite vocale'
vmtOutgoing = u'Sortant'
vmtUnknown = u'Inconnu'
vssAvailable = u'Disponible'
vssNotAvailable = u'Indisponible'
vssPaused = u'En pause'
vssRejected = u'Rejet\xe9'
vssRunning = u'En cours'
vssStarting = u'D\xe9marrage'
vssStopping = u'En cours d\u2019arr\xeat'
vssUnknown = u'Inconnu'
