apiAttachAvailable = u'API el\xe9rheto'
apiAttachNotAvailable = u'Nem el\xe9rheto'
apiAttachPendingAuthorization = u'F\xfcggoben l\xe9vo visszaigazol\xe1s'
apiAttachRefused = u'Elutas\xedtva'
apiAttachSuccess = u'Siker\xfclt'
apiAttachUnknown = u'Ismeretlen'
budDeletedFriend = u'T\xf6r\xf6lve a bar\xe1tok list\xe1j\xe1r\xf3l'
budFriend = u'Bar\xe1t'
budNeverBeenFriend = u'Soha nem volt a bar\xe1tok k\xf6z\xf6tt'
budPendingAuthorization = u'F\xfcggoben l\xe9vo visszaigazol\xe1s'
budUnknown = u'Ismeretlen'
cfrBlockedByRecipient = u'A h\xedv\xe1st blokkolta a c\xedmzett'
cfrMiscError = u'Egy\xe9b hiba'
cfrNoCommonCodec = u'Nincs szabv\xe1nyos kodek'
cfrNoProxyFound = u'Proxy nem tal\xe1lhat\xf3'
cfrNotAuthorizedByRecipient = u'A c\xedmzett nem igazolta vissza az aktu\xe1lis felhaszn\xe1l\xf3t'
cfrRecipientNotFriend = u'C\xedmzett nem tal\xe1lhat\xf3'
cfrRemoteDeviceError = u'Hanghiba a partnern\xe9l'
cfrSessionTerminated = u'V\xe9ge a h\xedv\xe1snak'
cfrSoundIOError = u'Hang I/O hiba'
cfrSoundRecordingError = u'Hangr\xf6gz\xedt\xe9si hiba'
cfrUnknown = u'Ismeretlen'
cfrUserDoesNotExist = u'A felhaszn\xe1l\xf3/telefonsz\xe1m nem l\xe9tezik'
cfrUserIsOffline = u'Kijelentkezett'
chsAllCalls = u'Kor\xe1bbi p\xe1rbesz\xe9d'
chsDialog = u'P\xe1rbesz\xe9d'
chsIncomingCalls = u'T\xf6bben akarj\xe1k fogadni'
chsLegacyDialog = u'Kor\xe1bbi p\xe1rbesz\xe9d'
chsMissedCalls = u'P\xe1rbesz\xe9d'
chsMultiNeedAccept = u'T\xf6bben akarj\xe1k fogadni'
chsMultiSubscribed = u'T\xf6bben feliratkoztak'
chsOutgoingCalls = u'T\xf6bben feliratkoztak'
chsUnknown = u'Ismeretlen'
chsUnsubscribed = u'Nincs feliratkozva'
clsBusy = u'Foglalt'
clsCancelled = u'Megszak\xedtva'
clsEarlyMedia = u'R\xe9gi zenesz\xe1m lej\xe1tsz\xe1sa'
clsFailed = u'A h\xedv\xe1s sikertelen.'
clsFinished = u'K\xe9sz'
clsInProgress = u'A besz\xe9lget\xe9s tart...'
clsLocalHold = u'Helyi h\xedv\xe1start\xe1s'
clsMissed = u'Nem fogadott h\xedv\xe1s tole:'
clsOnHold = u'H\xedv\xe1start\xe1s alatt'
clsRefused = u'Elutas\xedtva'
clsRemoteHold = u'T\xe1voli h\xedv\xe1start\xe1s'
clsRinging = u'h\xedv\xe1s'
clsRouting = u'\xdatvonal ir\xe1ny\xedt\xe1s'
clsTransferred = u'Ismeretlen'
clsTransferring = u'Ismeretlen'
clsUnknown = u'Ismeretlen'
clsUnplaced = u'Soha nem h\xedvta'
clsVoicemailBufferingGreeting = u'K\xf6sz\xf6nt\xe9s pufferel\xe9se'
clsVoicemailCancelled = u'Hang\xfczenet megszak\xedtva'
clsVoicemailFailed = u'Hang\xfczenet-hiba'
clsVoicemailPlayingGreeting = u'K\xf6sz\xf6nt\xe9s lej\xe1tsz\xe1sa'
clsVoicemailRecording = u'Hang\xfczenet felv\xe9tele t\xf6rt\xe9nik'
clsVoicemailSent = u'Hang\xfczenet elk\xfcldve'
clsVoicemailUploading = u'Hang\xfczenet felt\xf6lt\xe9se'
cltIncomingP2P = u'Bej\xf6vo k\xf6zvetlen h\xedv\xe1s'
cltIncomingPSTN = u'Bej\xf6vo telefonh\xedv\xe1s'
cltOutgoingP2P = u'Kimeno k\xf6zvetlen h\xedv\xe1s'
cltOutgoingPSTN = u'Kimeno telefonh\xedv\xe1s'
cltUnknown = u'Ismeretlen'
cmeAddedMembers = u'Hozz\xe1adott tagok'
cmeCreatedChatWith = u'Cseveg\xe9s l\xe9trehozva'
cmeEmoted = u'Ismeretlen'
cmeLeft = u'Elhagyta'
cmeSaid = u'Mondta'
cmeSawMembers = u'L\xe1tott tagok'
cmeSetTopic = u'T\xe9ma be\xe1ll\xedt\xe1sa'
cmeUnknown = u'Ismeretlen'
cmsRead = u'Elolvasva'
cmsReceived = u'Meg\xe9rkezett'
cmsSending = u'K\xfcld\xe9s...'
cmsSent = u'Elk\xfcldve'
cmsUnknown = u'Ismeretlen'
conConnecting = u'Kapcsol\xf3d\xe1s'
conOffline = u'Kijelentkezve'
conOnline = u'El\xe9rheto'
conPausing = u'Sz\xfcnetel'
conUnknown = u'Ismeretlen'
cusAway = u'Nincs a g\xe9pn\xe9l'
cusDoNotDisturb = u'Elfoglalt'
cusInvisible = u'L\xe1thatatlan'
cusLoggedOut = u'Kijelentkezve'
cusNotAvailable = u'Nem el\xe9rheto'
cusOffline = u'Kijelentkezve'
cusOnline = u'El\xe9rheto'
cusSkypeMe = u'H\xedv\xe1sk\xe9sz'
cusUnknown = u'Ismeretlen'
cvsBothEnabled = u'Vide\xf3 k\xfcld\xe9s \xe9s fogad\xe1s'
cvsNone = u'Nincs vide\xf3'
cvsReceiveEnabled = u'Vide\xf3 fogad\xe1s'
cvsSendEnabled = u'Vide\xf3 k\xfcld\xe9s'
cvsUnknown = u''
grpAllFriends = u'Minden bar\xe1t'
grpAllUsers = u'Minden felhaszn\xe1l\xf3'
grpCustomGroup = u'Egyedi'
grpOnlineFriends = u'El\xe9rheto bar\xe1tok'
grpPendingAuthorizationFriends = u'F\xfcggoben l\xe9vo visszaigazol\xe1s'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Legut\xf3bb keresett felhaszn\xe1l\xf3k'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype bar\xe1tok'
grpSkypeOutFriends = u'SkypeOut bar\xe1tok'
grpUngroupedFriends = u'Nem csoportos\xedtott bar\xe1tok'
grpUnknown = u'Ismeretlen'
grpUsersAuthorizedByMe = u'Visszaigazoltak'
grpUsersBlockedByMe = u'Blokkoltak'
grpUsersWaitingMyAuthorization = u'Visszaigazol\xe1sra v\xe1rakoz\xf3k'
leaAddDeclined = u'Hozz\xe1ad\xe1s elutas\xedtva'
leaAddedNotAuthorized = u'A hozz\xe1adott szem\xe9lyt vissza kell igazolni'
leaAdderNotFriend = u'A hozz\xe1ad\xf3nak bar\xe1tnak kell lennie'
leaUnknown = u'Ismeretlen'
leaUnsubscribe = u'Nincs feliratkozva'
leaUserIncapable = u'Felhaszn\xe1l\xf3 nem tudja'
leaUserNotFound = u'Felhaszn\xe1l\xf3 nem tal\xe1lhat\xf3'
olsAway = u'Nincs a g\xe9pn\xe9l'
olsDoNotDisturb = u'Elfoglalt'
olsNotAvailable = u'Nem el\xe9rheto'
olsOffline = u'Kijelentkezve'
olsOnline = u'El\xe9rheto'
olsSkypeMe = u'H\xedv\xe1sk\xe9sz'
olsSkypeOut = u'SkypeOut (?????-????)'
olsUnknown = u'Ismeretlen'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'no'
usexMale = u'f\xe9rfi'
usexUnknown = u'Ismeretlen'
vmrConnectError = u'Csatlakoz\xe1si hiba'
vmrFileReadError = u'F\xe1jl olvas\xe1si hiba'
vmrFileWriteError = u'F\xe1jl \xedr\xe1si hiba'
vmrMiscError = u'Egy\xe9b hiba'
vmrNoError = u'Nincs hiba'
vmrNoPrivilege = u'Nincs hang\xfczenet jogosults\xe1ga'
vmrNoVoicemail = u'Nincs ilyen hang\xfczenet'
vmrPlaybackError = u'Visszaj\xe1tsz\xe1si hiba'
vmrRecordingError = u'Hib\xe1s felv\xe9tel'
vmrUnknown = u'Ismeretlen'
vmsBlank = u'\xdcres'
vmsBuffering = u'Pufferel\xe9s'
vmsDeleting = u'T\xf6rl\xe9s'
vmsDownloading = u'Let\xf6lt\xe9s'
vmsFailed = u'Nem siker\xfclt'
vmsNotDownloaded = u'Nincs let\xf6ltve'
vmsPlayed = u'Lej\xe1tszott'
vmsPlaying = u'Lej\xe1tsz\xe1s'
vmsRecorded = u'R\xf6gz\xedtett'
vmsRecording = u'Hang\xfczenet felv\xe9tele t\xf6rt\xe9nik'
vmsUnknown = u'Ismeretlen'
vmsUnplayed = u'Nem lej\xe1tszott'
vmsUploaded = u'Felt\xf6ltve'
vmsUploading = u'Felt\xf6lt\xe9s'
vmtCustomGreeting = u'Egy\xe9ni k\xf6sz\xf6nt\xe9s'
vmtDefaultGreeting = u'Alap\xe9rtelmezett k\xf6sz\xf6nt\xe9s'
vmtIncoming = u'Hang\xfczenet \xe9rkezik'
vmtOutgoing = u'Kimeno'
vmtUnknown = u'Ismeretlen'
vssAvailable = u'El\xe9rheto'
vssNotAvailable = u'Nem el\xe9rheto'
vssPaused = u'Sz\xfcnetel'
vssRejected = u'Visszautas\xedtva'
vssRunning = u'Fut'
vssStarting = u'Ind\xedt\xe1s'
vssStopping = u'Le\xe1ll\xedt\xe1s'
vssUnknown = u'Ismeretlen'
